(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    158029,       5572]
NotebookOptionsPosition[    142073,       5028]
NotebookOutlinePosition[    142487,       5044]
CellTagsIndexPosition[    142444,       5041]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Expansions based on Johns, Ellis and Lattimer", "Section"],

Cell["\<\
These are expansions from ApJ 473 (1996) 1020. \
\>", "Text",
 CellChangeTimes->{{3.6171238821832314`*^9, 3.617123890322051*^9}}],

Cell[CellGroupData[{

Cell["Non-degenerate and non-relativstic:", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pcoeff", "=", 
  RowBox[{
   SuperscriptBox["t", "2"], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"n", "+", "1"}]], 
   RowBox[{
    RowBox[{"Exp", "[", 
     RowBox[{"n", 
      RowBox[{"(", 
       RowBox[{"\[Psi]", "+", 
        RowBox[{"1", "/", "t"}]}], ")"}]}], "]"}], "/", 
    SuperscriptBox["n", "2"]}]}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"1", "+", "n"}]], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"n", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "t"], "+", "\[Psi]"}], ")"}]}]], " ", 
   SuperscriptBox["t", "2"]}], 
  SuperscriptBox["n", "2"]]], "Output",
 CellChangeTimes->{3.617123909597927*^9, 3.617211950749998*^9, 
  3.6172392660061913`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"besselseries", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"BesselK", "[", 
       RowBox[{"2", ",", "x"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "\[Infinity]", ",", "6"}], "}"}]}], "]"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", "x"}]], " ", 
   SqrtBox[
    FractionBox["\[Pi]", "2"]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox["1", "x"], ")"}], 
    RowBox[{"11", "/", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "135135"}], "+", 
     RowBox[{"83160", " ", "x"}], "-", 
     RowBox[{"80640", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"215040", " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"491520", " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{"262144", " ", 
      SuperscriptBox["x", "5"]}]}], ")"}]}], "262144"]], "Output",
 CellChangeTimes->{3.617123910690125*^9, 3.617211951342257*^9, 
  3.617239266478582*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pNDNR", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"pcoeff", " ", 
    RowBox[{"(", 
     RowBox[{"besselseries", "/.", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{"n", "/", "t"}]}]}], ")"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"262144", " ", 
     SuperscriptBox["n", "5"]}]], 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"n", " ", "\[Psi]"}]], " ", 
    SqrtBox[
     FractionBox["\[Pi]", "2"]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["t", "n"], ")"}], 
     RowBox[{"5", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"262144", " ", 
       SuperscriptBox["n", "5"]}], "+", 
      RowBox[{"491520", " ", 
       SuperscriptBox["n", "4"], " ", "t"}], "+", 
      RowBox[{"215040", " ", 
       SuperscriptBox["n", "3"], " ", 
       SuperscriptBox["t", "2"]}], "-", 
      RowBox[{"80640", " ", 
       SuperscriptBox["n", "2"], " ", 
       SuperscriptBox["t", "3"]}], "+", 
      RowBox[{"83160", " ", "n", " ", 
       SuperscriptBox["t", "4"]}], "-", 
      RowBox[{"135135", " ", 
       SuperscriptBox["t", "5"]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.6171239109799023`*^9, 3.6172119514651318`*^9, 
  3.617239266600382*^9}]
}, Open  ]],

Cell["\<\
Separate out the first term to make the expansion more clear:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"firstterm", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"pNDNR", "/", 
        SuperscriptBox["t", 
         RowBox[{"5", "/", "2"}]]}], ",", 
       RowBox[{"t", ">", "0"}]}], "]"}], "/.", 
     RowBox[{"t", "\[Rule]", "0"}]}], ")"}], 
   SuperscriptBox["t", 
    RowBox[{"5", "/", "2"}]]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "n"]}], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"n", " ", "\[Psi]"}]], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    FractionBox["1", "n"], ")"}], 
   RowBox[{"5", "/", "2"}]], " ", 
  SqrtBox[
   FractionBox["\[Pi]", "2"]], " ", 
  SuperscriptBox["t", 
   RowBox[{"5", "/", "2"}]]}]], "Output",
 CellChangeTimes->{3.617123911085487*^9, 3.6172119515881844`*^9, 
  3.617239266699773*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pNDNRsimp", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"firstterm", ",", 
       RowBox[{"pNDNR", "/", "firstterm"}]}], "}"}], ",", 
     RowBox[{"n", ">", "0"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"n", " ", "\[Psi]"}]], " ", 
      SqrtBox[
       FractionBox["\[Pi]", "2"]], " ", 
      SuperscriptBox["t", "2"], " ", 
      SqrtBox[
       FractionBox["t", "n"]]}], 
     SuperscriptBox["n", "2"]]}], ",", 
   RowBox[{"1", "+", 
    FractionBox[
     RowBox[{"15", " ", "t"}], 
     RowBox[{"8", " ", "n"}]], "+", 
    FractionBox[
     RowBox[{"105", " ", 
      SuperscriptBox["t", "2"]}], 
     RowBox[{"128", " ", 
      SuperscriptBox["n", "2"]}]], "-", 
    FractionBox[
     RowBox[{"315", " ", 
      SuperscriptBox["t", "3"]}], 
     RowBox[{"1024", " ", 
      SuperscriptBox["n", "3"]}]], "+", 
    FractionBox[
     RowBox[{"10395", " ", 
      SuperscriptBox["t", "4"]}], 
     RowBox[{"32768", " ", 
      SuperscriptBox["n", "4"]}]], "-", 
    FractionBox[
     RowBox[{"135135", " ", 
      SuperscriptBox["t", "5"]}], 
     RowBox[{"262144", " ", 
      SuperscriptBox["n", "5"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.617123911135181*^9, 3.617211951632945*^9, 
  3.6172392667564983`*^9}]
}, Open  ]],

Cell["Calculate the number and energy densities:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Rho]NDNR", "=", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"pNDNR", ",", "\[Psi]"}], "]"}], "/", "t"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"262144", " ", 
     SuperscriptBox["n", "4"], " ", "t"}]], 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"n", " ", "\[Psi]"}]], " ", 
    SqrtBox[
     FractionBox["\[Pi]", "2"]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["t", "n"], ")"}], 
     RowBox[{"5", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"262144", " ", 
       SuperscriptBox["n", "5"]}], "+", 
      RowBox[{"491520", " ", 
       SuperscriptBox["n", "4"], " ", "t"}], "+", 
      RowBox[{"215040", " ", 
       SuperscriptBox["n", "3"], " ", 
       SuperscriptBox["t", "2"]}], "-", 
      RowBox[{"80640", " ", 
       SuperscriptBox["n", "2"], " ", 
       SuperscriptBox["t", "3"]}], "+", 
      RowBox[{"83160", " ", "n", " ", 
       SuperscriptBox["t", "4"]}], "-", 
      RowBox[{"135135", " ", 
       SuperscriptBox["t", "5"]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.617123911184834*^9, 3.617211951683913*^9, 
  3.61723926684057*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ft2", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"\[Rho]NDNR", "/", 
         SuperscriptBox["t", 
          RowBox[{"3", "/", "2"}]]}], ",", 
        RowBox[{"t", ">", "0"}]}], "]"}], "/.", 
      RowBox[{"t", "\[Rule]", "0"}]}], ")"}], 
    SuperscriptBox["t", 
     RowBox[{"3", "/", "2"}]]}]}], ";", 
  RowBox[{"\[Rho]NDNRsimp", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"ft2", ",", 
        RowBox[{"\[Rho]NDNR", "/", "ft2"}]}], "}"}], ",", 
      RowBox[{"t", ">", "0"}]}], "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"n", " ", "\[Psi]"}]], " ", 
      SqrtBox[
       FractionBox["\[Pi]", "2"]], " ", "t", " ", 
      SqrtBox[
       FractionBox["t", "n"]]}], "n"]}], ",", 
   RowBox[{"1", "+", 
    FractionBox[
     RowBox[{"15", " ", "t"}], 
     RowBox[{"8", " ", "n"}]], "+", 
    FractionBox[
     RowBox[{"105", " ", 
      SuperscriptBox["t", "2"]}], 
     RowBox[{"128", " ", 
      SuperscriptBox["n", "2"]}]], "-", 
    FractionBox[
     RowBox[{"315", " ", 
      SuperscriptBox["t", "3"]}], 
     RowBox[{"1024", " ", 
      SuperscriptBox["n", "3"]}]], "+", 
    FractionBox[
     RowBox[{"10395", " ", 
      SuperscriptBox["t", "4"]}], 
     RowBox[{"32768", " ", 
      SuperscriptBox["n", "4"]}]], "-", 
    FractionBox[
     RowBox[{"135135", " ", 
      SuperscriptBox["t", "5"]}], 
     RowBox[{"262144", " ", 
      SuperscriptBox["n", "5"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.61712391127337*^9, 3.617211951769574*^9, 
  3.617239266927546*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CurlyEpsilon]NDNR", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"t", " ", 
     RowBox[{"D", "[", 
      RowBox[{"pNDNR", ",", "t"}], "]"}]}], "-", "pNDNR", "+", "\[Rho]NDNR"}],
    "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"n", " ", "\[Psi]"}]], " ", 
    SqrtBox[
     FractionBox["\[Pi]", "2"]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["t", "n"], ")"}], 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"524288", " ", 
       SuperscriptBox["n", "6"]}], "+", 
      RowBox[{"1769472", " ", 
       SuperscriptBox["n", "5"], " ", "t"}], "+", 
      RowBox[{"2887680", " ", 
       SuperscriptBox["n", "4"], " ", 
       SuperscriptBox["t", "2"]}], "+", 
      RowBox[{"1344000", " ", 
       SuperscriptBox["n", "3"], " ", 
       SuperscriptBox["t", "3"]}], "-", 
      RowBox[{"559440", " ", 
       SuperscriptBox["n", "2"], " ", 
       SuperscriptBox["t", "4"]}], "+", 
      RowBox[{"644490", " ", "n", " ", 
       SuperscriptBox["t", "5"]}], "-", 
      RowBox[{"1756755", " ", 
       SuperscriptBox["t", "6"]}]}], ")"}]}], 
   RowBox[{"524288", " ", 
    SuperscriptBox["n", "6"]}]]}]], "Output",
 CellChangeTimes->{3.617123911412269*^9, 3.6172119520441437`*^9, 
  3.617239267008988*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ft3", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"\[CurlyEpsilon]NDNR", "/", 
         SuperscriptBox["t", 
          RowBox[{"3", "/", "2"}]]}], ",", 
        RowBox[{"t", ">", "0"}]}], "]"}], "/.", 
      RowBox[{"t", "\[Rule]", "0"}]}], ")"}], 
    SuperscriptBox["t", 
     RowBox[{"3", "/", "2"}]]}]}], ";", 
  RowBox[{"\[CurlyEpsilon]NDNRsimp", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"ft3", ",", 
        RowBox[{"\[CurlyEpsilon]NDNR", "/", "ft3"}]}], "}"}], ",", 
      RowBox[{"t", ">", "0"}]}], "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"n", " ", "\[Psi]"}]], " ", 
      SqrtBox[
       FractionBox["\[Pi]", "2"]], " ", "t", " ", 
      SqrtBox[
       FractionBox["t", "n"]]}], "n"]}], ",", 
   RowBox[{"1", "+", 
    FractionBox[
     RowBox[{"27", " ", "t"}], 
     RowBox[{"8", " ", "n"}]], "+", 
    FractionBox[
     RowBox[{"705", " ", 
      SuperscriptBox["t", "2"]}], 
     RowBox[{"128", " ", 
      SuperscriptBox["n", "2"]}]], "+", 
    FractionBox[
     RowBox[{"2625", " ", 
      SuperscriptBox["t", "3"]}], 
     RowBox[{"1024", " ", 
      SuperscriptBox["n", "3"]}]], "-", 
    FractionBox[
     RowBox[{"34965", " ", 
      SuperscriptBox["t", "4"]}], 
     RowBox[{"32768", " ", 
      SuperscriptBox["n", "4"]}]], "+", 
    FractionBox[
     RowBox[{"322245", " ", 
      SuperscriptBox["t", "5"]}], 
     RowBox[{"262144", " ", 
      SuperscriptBox["n", "5"]}]], "-", 
    FractionBox[
     RowBox[{"1756755", " ", 
      SuperscriptBox["t", "6"]}], 
     RowBox[{"524288", " ", 
      SuperscriptBox["n", "6"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.617123911538806*^9, 3.617211952243381*^9, 
  3.617239267119431*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The non-degenerate expansion from fermion_eval_thermo::calc_mu_ndeg():\
\>", "Subsubsection",
 CellChangeTimes->{{3.619359168164171*^9, 3.619359203325046*^9}}],

Cell["\<\
Verify the Bessel expansion (see e.g. Tooper Apj 156 (1969) 1075):\
\>", "Text",
 CellChangeTimes->{{3.619370957534151*^9, 3.61937098970183*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f1", "[", 
   RowBox[{"z_", ",", "\[Phi]_"}], "]"}], ":=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "2"], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["z", "2"]}], "]"}], "-", "\[Phi]"}], "]"}], "+", 
       "1"}], ")"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0.0", ",", "\[Infinity]"}], "}"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.6193709949447308`*^9, 3.619371034435314*^9}, 
   3.619371227843655*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f2", "[", 
   RowBox[{"z_", ",", "\[Phi]_"}], "]"}], ":=", 
  RowBox[{"NSum", "[", 
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "2"], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"n", "-", "1"}]], "/", "n"}], " ", 
     RowBox[{"Exp", "[", 
      RowBox[{"n", " ", "\[Phi]"}], "]"}], 
     RowBox[{"BesselK", "[", 
      RowBox[{"2", ",", 
       RowBox[{"n", " ", "z"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6193709949447308`*^9, 3.619371104142692*^9}, 
   3.6193712400439568`*^9, {3.6193717143942757`*^9, 3.619371724761888*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"f1", "[", 
    RowBox[{"1", ",", "0.5"}], "]"}], ",", 
   RowBox[{"f2", "[", 
    RowBox[{"1", ",", "0.5"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.619371136091387*^9, 3.6193711682645893`*^9}, {
  3.619371236928969*^9, 3.6193712444002323`*^9}, {3.619371682967602*^9, 
  3.6193717086460323`*^9}, {3.619371750839424*^9, 3.6193717593179283`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.4028038152387428`", ",", "2.4026953179733774`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.619371151194454*^9, 3.619371194765201*^9, {3.619371229876823*^9, 
   3.619371244708847*^9}, {3.619371683647709*^9, 3.6193717597273083`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"f1", "[", 
    RowBox[{"10", ",", "9"}], "]"}], ",", 
   RowBox[{"f2", "[", 
    RowBox[{"10", ",", "9"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.619371136091387*^9, 3.6193711682645893`*^9}, {
  3.619371236928969*^9, 3.619371264351536*^9}, {3.619371804511025*^9, 
  3.6193718207267933`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15.679819915143105`", ",", "15.67980595078742`"}], "}"}]], "Output",\

 CellChangeTimes->{
  3.619371151194454*^9, 3.619371194765201*^9, {3.619371229876823*^9, 
   3.619371264700927*^9}, {3.6193718101721697`*^9, 3.619371821092669*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pn", "=", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"1", "+", "n"}]], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"n", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", "t"], "+", "\[Psi]"}], ")"}]}]], " ", 
    SuperscriptBox["t", "2"], " ", 
    RowBox[{"BesselK", "[", 
     RowBox[{"2", ",", 
      FractionBox["n", "t"]}], "]"}]}], 
   SuperscriptBox["n", "2"]]}]], "Input",
 CellChangeTimes->{{3.619371058864149*^9, 3.619371059976244*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"1", "+", "n"}]], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"n", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "t"], "+", "\[Psi]"}], ")"}]}]], " ", 
   SuperscriptBox["t", "2"], " ", 
   RowBox[{"BesselK", "[", 
    RowBox[{"2", ",", 
     FractionBox["n", "t"]}], "]"}]}], 
  SuperscriptBox["n", "2"]]], "Output",
 CellChangeTimes->{3.619359245480908*^9, 3.6193710608973846`*^9}]
}, Open  ]],

Cell["The density:", "Text",
 CellChangeTimes->{{3.619359311012843*^9, 3.61935931241965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nndeg", "=", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"Pn", ",", "\[Psi]"}], "]"}], 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Mu]", "-", "m"}], ")"}], "/", "T"}], ",", "\[Mu]"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6193592536769867`*^9, 3.619359259550768*^9}, {
  3.619359290198373*^9, 3.6193593035760117`*^9}, {3.6193593827687693`*^9, 
  3.619359385551556*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"1", "+", "n"}]], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"n", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "t"], "+", "\[Psi]"}], ")"}]}]], " ", 
   SuperscriptBox["t", "2"], " ", 
   RowBox[{"BesselK", "[", 
    RowBox[{"2", ",", 
     FractionBox["n", "t"]}], "]"}]}], 
  RowBox[{"n", " ", "T"}]]], "Output",
 CellChangeTimes->{3.619359259902618*^9, 3.619359304350585*^9, 
  3.619359386141686*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"nndeg", "-", 
   RowBox[{"n", " ", 
    RowBox[{"Pn", "/", "T"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.619359387204315*^9, 3.619359394726527*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6193593951571827`*^9}]
}, Open  ]],

Cell["The entropy density:", "Text",
 CellChangeTimes->{{3.6193593150526247`*^9, 3.619359319195606*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sndeg", "=", 
  RowBox[{
   RowBox[{"0", 
    RowBox[{"D", "[", 
     RowBox[{"Pn", ",", "\[Psi]"}], "]"}], 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]", "-", "m"}], ")"}], "/", "T"}], ",", "T"}], "]"}]}], 
   "+", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{"Pn", ",", "t"}], "]"}], 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"T", "/", "m"}], ",", "T"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.619359320269415*^9, 3.619359361961705*^9}, {
   3.619359407914003*^9, 3.619359412872617*^9}, {3.619359971872979*^9, 
   3.619359979016526*^9}, 3.619360052400321*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "m"], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"1", "+", "n"}]], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"n", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "t"], "+", "\[Psi]"}], ")"}]}]], " ", 
       RowBox[{"BesselK", "[", 
        RowBox[{"2", ",", 
         FractionBox["n", "t"]}], "]"}]}], "n"]}], "+", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"1", "+", "n"}]], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"n", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", "t"], "+", "\[Psi]"}], ")"}]}]], " ", "t", " ", 
      RowBox[{"BesselK", "[", 
       RowBox[{"2", ",", 
        FractionBox["n", "t"]}], "]"}]}], 
     SuperscriptBox["n", "2"]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"1", "+", "n"}]], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"n", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", "t"], "+", "\[Psi]"}], ")"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"BesselK", "[", 
          RowBox[{"1", ",", 
           FractionBox["n", "t"]}], "]"}]}], "-", 
        RowBox[{"BesselK", "[", 
         RowBox[{"3", ",", 
          FractionBox["n", "t"]}], "]"}]}], ")"}]}], 
     RowBox[{"2", " ", "n"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.6193593623418407`*^9, 3.619359413245235*^9, {3.619359973163824*^9, 
   3.619359979898837*^9}, 3.6193600532080927`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"sndeg", "-", 
   RowBox[{
    RowBox[{"1", "/", "m"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"Pn", "/", "t"}]}], "-", 
      RowBox[{"n", " ", 
       RowBox[{
        RowBox[{"Pn", "/", "t"}], "/", "t"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          RowBox[{"n", "+", "1"}]], "/", "2"}], "/", "n"}], " ", 
       RowBox[{"Exp", "[", 
        RowBox[{"n", 
         RowBox[{"(", 
          RowBox[{"\[Psi]", "+", 
           RowBox[{"1", "/", "t"}]}], ")"}]}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"BesselK", "[", 
          RowBox[{"1", ",", 
           RowBox[{"n", "/", "t"}]}], "]"}], "+", 
         RowBox[{"BesselK", "[", 
          RowBox[{"3", ",", 
           RowBox[{"n", "/", "t"}]}], "]"}]}], ")"}]}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6193594021735373`*^9, 3.619359464099389*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.6193594645744953`*^9, {3.619359974531434*^9, 3.6193599810419188`*^9}, 
   3.6193600540176477`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "/", "Pn"}], "]"}]], "Input",
 CellChangeTimes->{{3.6193595502426043`*^9, 3.619359553570895*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"n", " ", 
   RowBox[{"(", 
    RowBox[{"m", "-", "\[Mu]"}], ")"}]}], 
  SuperscriptBox["T", "2"]]], "Output",
 CellChangeTimes->{3.61935955394938*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Non-degenerate and extremely relativistic:", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pcoeff", "=", 
  RowBox[{
   SuperscriptBox["t", "2"], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"n", "+", "1"}]], 
   RowBox[{
    RowBox[{"Exp", "[", 
     RowBox[{"n", " ", "\[Psi]"}], "]"}], "/", 
    SuperscriptBox["n", "2"]}]}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"1", "+", "n"}]], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"n", " ", "\[Psi]"}]], " ", 
   SuperscriptBox["t", "2"]}], 
  SuperscriptBox["n", "2"]]], "Output",
 CellChangeTimes->{3.617123911599276*^9, 3.61721195234254*^9, 
  3.6172392672999363`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bs", "=", 
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"BesselK", "[", 
      RowBox[{"2", ",", "x"}], "]"}], 
     RowBox[{"Exp", "[", "x", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "3"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox["2", 
    SuperscriptBox["x", "2"]], "+", 
   FractionBox["2", "x"], "+", 
   FractionBox["1", "2"], "-", 
   FractionBox["x", "6"], "+", 
   RowBox[{
    FractionBox["1", "96"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "7"}], "-", 
      RowBox[{"12", " ", "EulerGamma"}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"Log", "[", "2", "]"}]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"Log", "[", "x", "]"}]}]}], ")"}], " ", 
    SuperscriptBox["x", "2"]}], "+", 
   RowBox[{
    FractionBox["1", "480"], " ", 
    RowBox[{"(", 
     RowBox[{"13", "-", 
      RowBox[{"60", " ", "EulerGamma"}], "+", 
      RowBox[{"60", " ", 
       RowBox[{"Log", "[", "2", "]"}]}], "-", 
      RowBox[{"60", " ", 
       RowBox[{"Log", "[", "x", "]"}]}]}], ")"}], " ", 
    SuperscriptBox["x", "3"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "x", "]"}], "4"],
    SeriesData[$CellContext`x, 0, {}, -2, 4, 1],
    Editable->False]}],
  SeriesData[$CellContext`x, 0, {2, 2, 
    Rational[1, 2], 
    Rational[-1, 6], 
    Rational[1, 96] (-7 - 12 EulerGamma + 12 Log[2] - 12 Log[$CellContext`x]),
     Rational[1, 480] (13 - 60 EulerGamma + 60 Log[2] - 60 
     Log[$CellContext`x])}, -2, 4, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.6171239118187943`*^9, 3.6172119525510397`*^9, 
  3.617239267463729*^9}]
}, Open  ]],

Cell["Separate the individual terms:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bs2", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Normal", "[", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"BesselK", "[", 
         RowBox[{"2", ",", "x"}], "]"}], 
        RowBox[{"Exp", "[", "x", "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], ",", 
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{"bs", ",", "2"}], "]"}], ",", 
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{"bs", ",", "3"}], "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], "+", 
    FractionBox["2", 
     SuperscriptBox["x", "2"]], "+", 
    FractionBox["2", "x"], "-", 
    FractionBox["x", "6"]}], ",", 
   RowBox[{
    FractionBox["1", "96"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "7"}], "-", 
      RowBox[{"12", " ", "EulerGamma"}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"Log", "[", "2", "]"}]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"Log", "[", "x", "]"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "480"], " ", 
    RowBox[{"(", 
     RowBox[{"13", "-", 
      RowBox[{"60", " ", "EulerGamma"}], "+", 
      RowBox[{"60", " ", 
       RowBox[{"Log", "[", "2", "]"}]}], "-", 
      RowBox[{"60", " ", 
       RowBox[{"Log", "[", "x", "]"}]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.617123912029963*^9, 3.617211952592724*^9, 
  3.617239267520473*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pNDER", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"pcoeff", " ", 
    RowBox[{"(", 
     RowBox[{"bs2", "/.", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{"n", "/", "t"}]}]}], ")"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"n", " ", "\[Psi]"}]], " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["n", "3"], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["n", "2"], " ", "t"}], "-", 
       RowBox[{"12", " ", "n", " ", 
        SuperscriptBox["t", "2"]}], "-", 
       RowBox[{"12", " ", 
        SuperscriptBox["t", "3"]}]}], ")"}]}], 
    RowBox[{"6", " ", 
     SuperscriptBox["n", "4"]}]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"n", " ", "\[Psi]"}]], " ", 
     SuperscriptBox["t", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"7", "+", 
       RowBox[{"12", " ", "EulerGamma"}], "-", 
       RowBox[{"12", " ", 
        RowBox[{"Log", "[", "2", "]"}]}], "+", 
       RowBox[{"12", " ", 
        RowBox[{"Log", "[", 
         FractionBox["n", "t"], "]"}]}]}], ")"}]}], 
    RowBox[{"96", " ", 
     SuperscriptBox["n", "2"]}]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"n", " ", "\[Psi]"}]], " ", 
     SuperscriptBox["t", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "13"}], "+", 
       RowBox[{"60", " ", "EulerGamma"}], "-", 
       RowBox[{"60", " ", 
        RowBox[{"Log", "[", "2", "]"}]}], "+", 
       RowBox[{"60", " ", 
        RowBox[{"Log", "[", 
         FractionBox["n", "t"], "]"}]}]}], ")"}]}], 
    RowBox[{"480", " ", 
     SuperscriptBox["n", "2"]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.6171239122304163`*^9, 3.617211952650227*^9, 
  3.617239267585285*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coefx", "=", 
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   SuperscriptBox["t", "4"], 
   RowBox[{"Exp", "[", 
    RowBox[{"n", " ", "\[Psi]"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], "/", 
    SuperscriptBox["n", "4"]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"n", " ", "\[Psi]"}]], " ", 
    SuperscriptBox["t", "4"]}], 
   SuperscriptBox["n", "4"]]}]], "Output",
 CellChangeTimes->{3.617123912450301*^9, 3.617211952691331*^9, 
  3.617239267653665*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pNDERsimp", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"{", 
    RowBox[{"coefx", ",", 
     RowBox[{"pNDER", "/", "coefx"}]}], "}"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"n", " ", "\[Psi]"}]], " ", 
      SuperscriptBox["t", "4"]}], 
     SuperscriptBox["n", "4"]]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "-", 
      FractionBox[
       SuperscriptBox["n", "3"], 
       RowBox[{"12", " ", 
        SuperscriptBox["t", "3"]}]], "+", 
      FractionBox[
       SuperscriptBox["n", "2"], 
       RowBox[{"4", " ", 
        SuperscriptBox["t", "2"]}]], "+", 
      FractionBox["n", "t"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"7", " ", 
         SuperscriptBox["n", "2"]}], 
        RowBox[{"192", " ", 
         SuperscriptBox["t", "2"]}]]}], "-", 
      FractionBox[
       RowBox[{"EulerGamma", " ", 
        SuperscriptBox["n", "2"]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["t", "2"]}]], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["n", "2"], " ", 
        RowBox[{"Log", "[", "2", "]"}]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["t", "2"]}]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["n", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox["n", "t"], "]"}]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["t", "2"]}]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"13", " ", 
        SuperscriptBox["n", "2"]}], 
       RowBox[{"960", " ", 
        SuperscriptBox["t", "2"]}]], "-", 
      FractionBox[
       RowBox[{"EulerGamma", " ", 
        SuperscriptBox["n", "2"]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["t", "2"]}]], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["n", "2"], " ", 
        RowBox[{"Log", "[", "2", "]"}]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["t", "2"]}]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["n", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox["n", "t"], "]"}]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["t", "2"]}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6171239125965643`*^9, 3.617211952741437*^9, 
  3.617239267737026*^9}]
}, Open  ]],

Cell["Compute the number and energy densities:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Rho]NDER", "=", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"pNDER", ",", "\[Psi]"}], "]"}], "/", "t"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"n", " ", "\[Psi]"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["n", "3"], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["n", "2"], " ", "t"}], "-", 
       RowBox[{"12", " ", "n", " ", 
        SuperscriptBox["t", "2"]}], "-", 
       RowBox[{"12", " ", 
        SuperscriptBox["t", "3"]}]}], ")"}]}], 
    RowBox[{"6", " ", 
     SuperscriptBox["n", "3"]}]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"n", " ", "\[Psi]"}]], " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{"7", "+", 
       RowBox[{"12", " ", "EulerGamma"}], "-", 
       RowBox[{"12", " ", 
        RowBox[{"Log", "[", "2", "]"}]}], "+", 
       RowBox[{"12", " ", 
        RowBox[{"Log", "[", 
         FractionBox["n", "t"], "]"}]}]}], ")"}]}], 
    RowBox[{"96", " ", "n"}]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"n", " ", "\[Psi]"}]], " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "13"}], "+", 
       RowBox[{"60", " ", "EulerGamma"}], "-", 
       RowBox[{"60", " ", 
        RowBox[{"Log", "[", "2", "]"}]}], "+", 
       RowBox[{"60", " ", 
        RowBox[{"Log", "[", 
         FractionBox["n", "t"], "]"}]}]}], ")"}]}], 
    RowBox[{"480", " ", "n"}]]}], "}"}]], "Output",
 CellChangeTimes->{3.617123912679448*^9, 3.617211952791841*^9, 
  3.617239267801021*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coefx2", "=", 
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   SuperscriptBox["t", "3"], 
   RowBox[{"Exp", "[", 
    RowBox[{"n", " ", "\[Psi]"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], "/", 
    SuperscriptBox["n", "3"]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"n", " ", "\[Psi]"}]], " ", 
    SuperscriptBox["t", "3"]}], 
   SuperscriptBox["n", "3"]]}]], "Output",
 CellChangeTimes->{3.617123912761593*^9, 3.617211952922429*^9, 
  3.617239267869575*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Rho]NDERsimp", "=", 
  RowBox[{"{", 
   RowBox[{"coefx2", ",", 
    RowBox[{"Expand", "[", 
     RowBox[{"\[Rho]NDER", "/", "coefx2"}], "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"n", " ", "\[Psi]"}]], " ", 
      SuperscriptBox["t", "3"]}], 
     SuperscriptBox["n", "3"]]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "-", 
      FractionBox[
       SuperscriptBox["n", "3"], 
       RowBox[{"12", " ", 
        SuperscriptBox["t", "3"]}]], "+", 
      FractionBox[
       SuperscriptBox["n", "2"], 
       RowBox[{"4", " ", 
        SuperscriptBox["t", "2"]}]], "+", 
      FractionBox["n", "t"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"7", " ", 
         SuperscriptBox["n", "2"]}], 
        RowBox[{"192", " ", 
         SuperscriptBox["t", "2"]}]]}], "-", 
      FractionBox[
       RowBox[{"EulerGamma", " ", 
        SuperscriptBox["n", "2"]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["t", "2"]}]], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["n", "2"], " ", 
        RowBox[{"Log", "[", "2", "]"}]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["t", "2"]}]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["n", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox["n", "t"], "]"}]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["t", "2"]}]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"13", " ", 
        SuperscriptBox["n", "2"]}], 
       RowBox[{"960", " ", 
        SuperscriptBox["t", "2"]}]], "-", 
      FractionBox[
       RowBox[{"EulerGamma", " ", 
        SuperscriptBox["n", "2"]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["t", "2"]}]], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["n", "2"], " ", 
        RowBox[{"Log", "[", "2", "]"}]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["t", "2"]}]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["n", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox["n", "t"], "]"}]}], 
       RowBox[{"16", " ", 
        SuperscriptBox["t", "2"]}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6171239128110743`*^9, 3.617211952972404*^9, 
  3.6172392679366837`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CurlyEpsilon]NDER", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"t", " ", 
     RowBox[{"D", "[", 
      RowBox[{"pNDER", ",", "t"}], "]"}]}], "-", "pNDER", "+", "\[Rho]NDER"}],
    "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"n", " ", "\[Psi]"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["n", "4"], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["n", "3"], " ", "t"}], "-", 
       RowBox[{"15", " ", 
        SuperscriptBox["n", "2"], " ", 
        SuperscriptBox["t", "2"]}], "-", 
       RowBox[{"36", " ", "n", " ", 
        SuperscriptBox["t", "3"]}], "-", 
       RowBox[{"36", " ", 
        SuperscriptBox["t", "4"]}]}], ")"}]}], 
    RowBox[{"6", " ", 
     SuperscriptBox["n", "4"]}]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"n", " ", "\[Psi]"}]], " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"t", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"12", " ", "EulerGamma"}], "-", 
          RowBox[{"12", " ", 
           RowBox[{"Log", "[", "2", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"n", " ", 
        RowBox[{"(", 
         RowBox[{"7", "+", 
          RowBox[{"12", " ", "EulerGamma"}], "-", 
          RowBox[{"12", " ", 
           RowBox[{"Log", "[", "2", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"12", " ", 
        RowBox[{"(", 
         RowBox[{"n", "+", "t"}], ")"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox["n", "t"], "]"}]}]}], ")"}]}], 
    RowBox[{"96", " ", 
     SuperscriptBox["n", "2"]}]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"n", " ", "\[Psi]"}]], " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"t", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "73"}], "+", 
          RowBox[{"60", " ", "EulerGamma"}], "-", 
          RowBox[{"60", " ", 
           RowBox[{"Log", "[", "2", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"n", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "13"}], "+", 
          RowBox[{"60", " ", "EulerGamma"}], "-", 
          RowBox[{"60", " ", 
           RowBox[{"Log", "[", "2", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"60", " ", 
        RowBox[{"(", 
         RowBox[{"n", "+", "t"}], ")"}], " ", 
        RowBox[{"Log", "[", 
         FractionBox["n", "t"], "]"}]}]}], ")"}]}], 
    RowBox[{"480", " ", 
     SuperscriptBox["n", "2"]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.617123912909264*^9, 3.61721195306675*^9, 
  3.6172392680363493`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coefx3", "=", 
  RowBox[{
   RowBox[{"-", "6"}], " ", 
   SuperscriptBox["t", "3"], 
   RowBox[{"Exp", "[", 
    RowBox[{"n", " ", "\[Psi]"}], "]"}], 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], "/", 
    SuperscriptBox["n", "3"]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"6", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"n", " ", "\[Psi]"}]], " ", 
    SuperscriptBox["t", "3"]}], 
   SuperscriptBox["n", "3"]]}]], "Output",
 CellChangeTimes->{3.617123913040554*^9, 3.6172119531043873`*^9, 
  3.6172392681022463`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CurlyEpsilon]NDERsimp", "=", 
  RowBox[{"{", 
   RowBox[{"coefx3", ",", 
    RowBox[{"Expand", "[", 
     RowBox[{"\[CurlyEpsilon]NDER", "/", "coefx3"}], "]"}]}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"6", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"n", " ", "\[Psi]"}]], " ", 
      SuperscriptBox["t", "3"]}], 
     SuperscriptBox["n", "3"]]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "-", 
      FractionBox[
       SuperscriptBox["n", "3"], 
       RowBox[{"36", " ", 
        SuperscriptBox["t", "3"]}]], "+", 
      FractionBox[
       SuperscriptBox["n", "2"], 
       RowBox[{"12", " ", 
        SuperscriptBox["t", "2"]}]], "+", 
      FractionBox[
       RowBox[{"5", " ", "n"}], 
       RowBox[{"12", " ", "t"}]], "+", 
      FractionBox["t", "n"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"7", " ", 
         SuperscriptBox["n", "2"]}], 
        RowBox[{"576", " ", 
         SuperscriptBox["t", "2"]}]]}], "-", 
      FractionBox[
       RowBox[{"EulerGamma", " ", 
        SuperscriptBox["n", "2"]}], 
       RowBox[{"48", " ", 
        SuperscriptBox["t", "2"]}]], "+", 
      FractionBox[
       RowBox[{"5", " ", "n"}], 
       RowBox[{"576", " ", "t"}]], "-", 
      FractionBox[
       RowBox[{"EulerGamma", " ", "n"}], 
       RowBox[{"48", " ", "t"}]], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["n", "2"], " ", 
        RowBox[{"Log", "[", "2", "]"}]}], 
       RowBox[{"48", " ", 
        SuperscriptBox["t", "2"]}]], "+", 
      FractionBox[
       RowBox[{"n", " ", 
        RowBox[{"Log", "[", "2", "]"}]}], 
       RowBox[{"48", " ", "t"}]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["n", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox["n", "t"], "]"}]}], 
       RowBox[{"48", " ", 
        SuperscriptBox["t", "2"]}]], "-", 
      FractionBox[
       RowBox[{"n", " ", 
        RowBox[{"Log", "[", 
         FractionBox["n", "t"], "]"}]}], 
       RowBox[{"48", " ", "t"}]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"13", " ", 
        SuperscriptBox["n", "2"]}], 
       RowBox[{"2880", " ", 
        SuperscriptBox["t", "2"]}]], "-", 
      FractionBox[
       RowBox[{"EulerGamma", " ", 
        SuperscriptBox["n", "2"]}], 
       RowBox[{"48", " ", 
        SuperscriptBox["t", "2"]}]], "+", 
      FractionBox[
       RowBox[{"73", " ", "n"}], 
       RowBox[{"2880", " ", "t"}]], "-", 
      FractionBox[
       RowBox[{"EulerGamma", " ", "n"}], 
       RowBox[{"48", " ", "t"}]], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["n", "2"], " ", 
        RowBox[{"Log", "[", "2", "]"}]}], 
       RowBox[{"48", " ", 
        SuperscriptBox["t", "2"]}]], "+", 
      FractionBox[
       RowBox[{"n", " ", 
        RowBox[{"Log", "[", "2", "]"}]}], 
       RowBox[{"48", " ", "t"}]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["n", "2"], " ", 
        RowBox[{"Log", "[", 
         FractionBox["n", "t"], "]"}]}], 
       RowBox[{"48", " ", 
        SuperscriptBox["t", "2"]}]], "-", 
      FractionBox[
       RowBox[{"n", " ", 
        RowBox[{"Log", "[", 
         FractionBox["n", "t"], "]"}]}], 
       RowBox[{"48", " ", "t"}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.61712391309046*^9, 3.617211953155939*^9, 
  3.6172392681674423`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The extremely degenerate case:", "Subsubsection"],

Cell["\<\
The pressure from JEL (this integral is from 0 to \[Infinity]):\
\>", "Text",
 CellChangeTimes->{{3.617123953143158*^9, 3.617123967073299*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p", "=", 
  RowBox[{
   RowBox[{"1", "/", "3"}], " ", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", "l", "]"}], 
      RowBox[{
       RowBox[{
        SuperscriptBox["l", "4"], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          SuperscriptBox["l", "2"], "+", "1"}], "]"}]}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", 
               RowBox[{
                SuperscriptBox["l", "2"], "+", "1"}], "]"}], "-", "1"}], 
             ")"}], "/", "t"}], "-", "\[Psi]"}], "]"}]}], ")"}]}]}], ",", 
     "l"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6171239262210608`*^9, 3.617123939175576*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "3"], " ", 
  RowBox[{"\[Integral]", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["l", "4"], " ", 
      RowBox[{"f", "[", "l", "]"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SqrtBox[
             RowBox[{"1", "+", 
              SuperscriptBox["l", "2"]}]]}], "t"], "-", "\[Psi]"}]]}], ")"}], 
      " ", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox["l", "2"]}]]}]], 
    RowBox[{"\[DifferentialD]", "l"}]}]}]}]], "Output",
 CellChangeTimes->{{3.6171239326301394`*^9, 3.61712394058434*^9}, 
   3.617211954193112*^9, 3.617239269233971*^9}]
}, Open  ]],

Cell[TextData[{
 "Change variables to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"l", "=", 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], "2"], "-", "1"}]]}], 
   TraditionalForm]]],
 "and \[Psi] t=x, and re-examine the integrand:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dldz", "=", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"Sqrt", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], "2"], "-", "1"}], "]"}], ",", "z"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "+", "z"}], 
  SqrtBox[
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "z"}], ")"}], "2"]}]]]], "Output",
 CellChangeTimes->{3.6171239895541277`*^9, 3.617211954318159*^9, 
  3.6172392699913797`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "l", "]"}], "dl"}], "\[Equal]", 
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], 
   RowBox[{"(", 
    RowBox[{"dl", "/", "dz"}], ")"}], " ", "dz"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dl", " ", 
   RowBox[{"f", "[", "l", "]"}]}], "\[Equal]", 
  RowBox[{"dl", " ", 
   RowBox[{"f", "[", "z", "]"}]}]}]], "Output",
 CellChangeTimes->{3.617123994169938*^9, 3.6172119543685217`*^9, 
  3.617239270123506*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"degiand", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["l", "4"], 
       RowBox[{
        RowBox[{
         RowBox[{"dldz", "/", "3"}], "/", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           SuperscriptBox["l", "2"], "+", "1"}], "]"}]}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Sqrt", "[", 
                RowBox[{
                 SuperscriptBox["l", "2"], "+", "1"}], "]"}], "-", "1"}], 
              ")"}], "/", "t"}], "-", "\[Psi]"}], "]"}]}], ")"}]}]}], "/.", 
      RowBox[{"l", "\[Rule]", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], "2"], "-", "1"}], "]"}]}]}], "/.", 
     
     RowBox[{"\[Psi]", "\[Rule]", 
      RowBox[{"x", "/", "t"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ">", "0"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    FractionBox["x", "t"]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"z", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", "z"}], ")"}]}], ")"}], 
    RowBox[{"3", "/", "2"}]]}], 
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox["x", "t"]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox["z", "t"]]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.617123997811635*^9, 3.6172119544673557`*^9, 
  3.617239270224121*^9}]
}, Open  ]],

Cell["Note that the limits are the same.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["l", "4"], "/", "3"}], "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        SuperscriptBox["l", "2"], "+", "1"}], "]"}]}], "/.", 
     RowBox[{"l", "\[Rule]", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], "2"], "-", "1"}], "]"}]}]}], "/.", 
    RowBox[{"\[Psi]", "\[Rule]", 
     RowBox[{"x", "/", "t"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ">", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.61721535834321*^9, 3.61721536199631*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["z", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"2", "+", "z"}], ")"}], "2"]}], 
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "z"}], ")"}]}]]], "Output",
 CellChangeTimes->{3.617215362707911*^9, 3.617239270323059*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dldz", "/.", 
     RowBox[{"l", "\[Rule]", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], "2"], "-", "1"}], "]"}]}]}], "/.", 
    RowBox[{"\[Psi]", "\[Rule]", 
     RowBox[{"x", "/", "t"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ">", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.61721535834321*^9, 3.6172153746174183`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "+", "z"}], 
  SqrtBox[
   RowBox[{"z", " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", "z"}], ")"}]}]]]], "Output",
 CellChangeTimes->{{3.617215362707911*^9, 3.6172153749991837`*^9}, 
   3.617239270572083*^9}]
}, Open  ]],

Cell["Separate out the Fermi function:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"newf", "=", 
  RowBox[{
   RowBox[{"degiand", "/", 
    RowBox[{"Exp", "[", 
     RowBox[{"x", "/", "t"}], "]"}]}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox["x", "t"]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox["z", "t"]]}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "3"], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"z", " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", "z"}], ")"}]}], ")"}], 
   RowBox[{"3", "/", "2"}]]}]], "Output",
 CellChangeTimes->{3.617124008355275*^9, 3.617211954568027*^9, 
  3.61723927062856*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"degiand", "-", 
   RowBox[{"newf", "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"z", "/", "t"}], "-", 
        RowBox[{"x", "/", "t"}]}], "]"}]}], ")"}]}]}], "]"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.617124009085359*^9, 3.617211954666341*^9, 
  3.617239270759838*^9}]
}, Open  ]],

Cell[TextData[{
 "At this point, we have recast the problem into an integral of the form:\n\
\[Integral] f(z)/(1 + ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", 
     RowBox[{
      RowBox[{"z", "/", "t"}], "-", 
      RowBox[{"x", "/", "t"}]}]], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "\nwhere f(z) is stored in \[OpenCurlyQuote]newf\[CloseCurlyQuote]."
}], "Text",
 CellChangeTimes->{{3.617124102914546*^9, 3.617124181673306*^9}}],

Cell["\<\
Now we can use the Sommerfeld expansion from Landau and Lifshitz, which is \
valid when \[Mu]/T (=x/t) is large.
Note that this is an asymptotic expansion, so we have to be careful about \
including too many terms.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", "\[Epsilon]", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[CurlyEpsilon]", "-", "\[Mu]"}], ")"}], "/", "T"}], 
          "]"}]}], ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyEpsilon]", ",", "0", ",", "\[Infinity]"}], "}"}]}], 
     "]"}], "\[Equal]", 
    RowBox[{
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"f", "[", "\[CurlyEpsilon]", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[CurlyEpsilon]", ",", "0", ",", "\[Mu]"}], "}"}]}], "]"}], 
     "+", 
     RowBox[{"Expand", "[", 
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"T", " ", 
         RowBox[{
          RowBox[{"Normal", "[", 
           RowBox[{"Series", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"f", "[", 
                RowBox[{"\[Mu]", "+", 
                 RowBox[{"T", " ", "z"}]}], "]"}], "-", 
               RowBox[{"f", "[", 
                RowBox[{"\[Mu]", "-", 
                 RowBox[{"T", " ", "z"}]}], "]"}]}], ")"}], ",", 
             RowBox[{"{", 
              RowBox[{"z", ",", "0", ",", "9"}], "}"}]}], "]"}], "]"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Exp", "[", "z", "]"}], "+", "1"}], ")"}]}]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "\[Infinity]"}], "}"}]}], "]"}], 
      "]"}]}]}], ",", 
   RowBox[{"T", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.617124208614421*^9, 3.617124233900896*^9}, {
  3.617124281024108*^9, 3.617124379042351*^9}, {3.617124458313999*^9, 
  3.617124472541522*^9}, {3.617124531755638*^9, 3.617124541883122*^9}, {
  3.617213182239971*^9, 3.617213182517058*^9}, {3.617214045624218*^9, 
  3.6172140554153547`*^9}, {3.617214329271153*^9, 3.6172143316270514`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"T", " ", 
   RowBox[{"f", "[", "\[Epsilon]", "]"}], " ", 
   RowBox[{"Log", "[", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox["\[Mu]", "T"]]}], "]"}]}], "\[Equal]", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "\[Mu]"], 
    RowBox[{
     RowBox[{"f", "[", "\[CurlyEpsilon]", "]"}], 
     RowBox[{"\[DifferentialD]", "\[CurlyEpsilon]"}]}]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    SuperscriptBox["\[Pi]", "2"], " ", 
    SuperscriptBox["T", "2"], " ", 
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "\[Mu]", "]"}]}], "+", 
   RowBox[{
    FractionBox["7", "360"], " ", 
    SuperscriptBox["\[Pi]", "4"], " ", 
    SuperscriptBox["T", "4"], " ", 
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", "3", ")"}],
       Derivative],
      MultilineFunction->None], "[", "\[Mu]", "]"}]}], "+", 
   FractionBox[
    RowBox[{"31", " ", 
     SuperscriptBox["\[Pi]", "6"], " ", 
     SuperscriptBox["T", "6"], " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "5", ")"}],
        Derivative],
       MultilineFunction->None], "[", "\[Mu]", "]"}]}], "15120"], "+", 
   FractionBox[
    RowBox[{"127", " ", 
     SuperscriptBox["\[Pi]", "8"], " ", 
     SuperscriptBox["T", "8"], " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "7", ")"}],
        Derivative],
       MultilineFunction->None], "[", "\[Mu]", "]"}]}], "604800"], "+", 
   FractionBox[
    RowBox[{"73", " ", 
     SuperscriptBox["\[Pi]", "10"], " ", 
     SuperscriptBox["T", "10"], " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "9", ")"}],
        Derivative],
       MultilineFunction->None], "[", "\[Mu]", "]"}]}], 
    "3421440"]}]}]], "Output",
 CellChangeTimes->{3.617124423590555*^9, 3.617124515596311*^9, 
  3.6172120086338863`*^9, 3.6172132675221977`*^9, 3.617214181269495*^9, 
  3.617214457276044*^9, 3.617239407158017*^9}]
}, Open  ]],

Cell["\<\
Show that this is the correct series:\
\>", "Text",
 CellChangeTimes->{{3.61723575651867*^9, 3.617235761916975*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "=", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"n", "+", "1"}]], "2", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["2", 
      RowBox[{
       RowBox[{"2", "n"}], " ", "-", "1"}]], "-", "1"}], ")"}], 
   RowBox[{
    RowBox[{"BernoulliB", "[", 
     RowBox[{"2", "n"}], "]"}], "/", 
    RowBox[{"Factorial", "[", 
     RowBox[{"2", "n"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6172143484355717`*^9, 3.6172143785459127`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"1", "+", "n"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["2", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", "n"}]}]]}], ")"}], " ", 
   RowBox[{"BernoulliB", "[", 
    RowBox[{"2", " ", "n"}], "]"}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"2", " ", "n"}], ")"}], "!"}]]], "Output",
 CellChangeTimes->{3.6172144579211197`*^9, 3.617239407389471*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "1", ",", "5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.617214514223075*^9, 3.61721454134374*^9}, {
  3.6172152951114283`*^9, 3.617215295256214*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "6"], ",", 
   FractionBox["7", "360"], ",", 
   FractionBox["31", "15120"], ",", 
   FractionBox["127", "604800"], ",", 
   FractionBox["73", "3421440"]}], "}"}]], "Output",
 CellChangeTimes->{{3.6172145218813562`*^9, 3.617214542044414*^9}, 
   3.617215296754031*^9, 3.617239407460785*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The use of this expansion for fermion_eval_thermo::calc_mu_deg():\
\>", "Subsubsection",
 CellChangeTimes->{{3.617124995932942*^9, 3.6171250127705727`*^9}}],

Cell["\<\
The first term in the pressure is:\
\>", "Text",
 CellChangeTimes->{{3.617124558236875*^9, 3.617124573724419*^9}, {
  3.617235784252099*^9, 3.6172357861623707`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p0", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"TrigToExp", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{"newf", ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "x"}], "}"}]}], "]"}], ",", 
      RowBox[{"x", ">", "0"}]}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.617124545628903*^9, 3.617124588250496*^9}, {
  3.617124639107875*^9, 3.6171246719642267`*^9}, {3.617235811954589*^9, 
  3.6172358151865683`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"x", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "x"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", "x"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "3"}], "+", 
      RowBox[{"2", " ", "x", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", "x"}], ")"}]}]}], ")"}]}], "+", 
   RowBox[{"6", " ", 
    SqrtBox[
     RowBox[{"x", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", "x"}], ")"}]}]], " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{
       SqrtBox["x"], "+", 
       SqrtBox[
        RowBox[{"2", "+", "x"}]]}], 
      SqrtBox["2"]], "]"}]}]}], 
  RowBox[{"24", " ", 
   SqrtBox[
    RowBox[{"x", " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", "x"}], ")"}]}]]}]]], "Output",
 CellChangeTimes->{
  3.617124546508955*^9, {3.617124582247781*^9, 3.6171245938409777`*^9}, {
   3.6171246481198387`*^9, 3.617124686073011*^9}, 3.6172120229555693`*^9, 
   3.617217624358224*^9, 3.61723590276987*^9, 3.617239423029201*^9, 
   3.617239582586936*^9}]
}, Open  ]],

Cell["But this behaves poorly when x is small, so we use:", "Text",
 CellChangeTimes->{{3.617124789073865*^9, 3.6171248002829943`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Normal", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"p0", " ", 
      RowBox[{"Sqrt", "[", "x", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "6"}], "}"}]}], "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.617124673277926*^9, 3.617124762925681*^9}, {
  3.617124834680735*^9, 3.6171248953961554`*^9}, {3.6172359583786592`*^9, 
  3.617235959082459*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["x", "3"], " ", 
   RowBox[{"(", 
    RowBox[{"29568", "+", 
     RowBox[{"15840", " ", "x"}], "+", 
     RowBox[{"1540", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"105", " ", 
      SuperscriptBox["x", "3"]}]}], ")"}]}], 
  RowBox[{"55440", " ", 
   SqrtBox["2"]}]]], "Output",
 CellChangeTimes->{{3.6171246862726383`*^9, 3.617124723706245*^9}, 
   3.6171247643324213`*^9, {3.6171248356619864`*^9, 3.617124895865363*^9}, 
   3.61723595945154*^9, 3.617239423270567*^9, 3.617239582838983*^9}]
}, Open  ]],

Cell["The second term is:", "Text",
 CellChangeTimes->{{3.617124912982442*^9, 3.6171249238727818`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{
   SuperscriptBox["t", "2"], 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[Pi]", "2"], "/", "6"}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{"newf", ",", "z"}], "]"}], "/.", 
     RowBox[{"z", "\[Rule]", "x"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.617124929677779*^9, 3.617124963659987*^9}, {
  3.61723596951626*^9, 3.6172359699568157`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "12"], " ", 
  SuperscriptBox["\[Pi]", "2"], " ", 
  SuperscriptBox["t", "2"], " ", 
  SqrtBox[
   RowBox[{"x", " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", "x"}], ")"}]}]], " ", 
  RowBox[{"(", 
   RowBox[{"2", "+", 
    RowBox[{"2", " ", "x"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.61712496415841*^9, 3.617235970375498*^9, 
  3.617239423374352*^9, 3.617239582971324*^9}]
}, Open  ]],

Cell["The third term is:", "Text",
 CellChangeTimes->{{3.617124912982442*^9, 3.6171249238727818`*^9}, {
  3.617125085940069*^9, 3.6171250873721457`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p2", "=", 
  RowBox[{
   SuperscriptBox["t", "4"], 
   RowBox[{"(", 
    RowBox[{"7", 
     RowBox[{
      SuperscriptBox["\[Pi]", "4"], "/", "360"}]}], ")"}], 
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{"newf", ",", "z"}], "]"}], ",", "z"}], "]"}], ",", "z"}], 
       "]"}], "/.", 
      RowBox[{"z", "\[Rule]", "x"}]}], ")"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.617124929677779*^9, 3.617124963659987*^9}, {
  3.617125098279904*^9, 3.6171251332203712`*^9}, {3.617235975829521*^9, 
  3.6172359760938*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"7", " ", 
   SuperscriptBox["\[Pi]", "4"], " ", 
   SuperscriptBox["t", "4"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "x"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"4", " ", "x"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}]}], 
  RowBox[{"360", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"x", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", "x"}], ")"}]}], ")"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.61712496415841*^9, {3.617125118022744*^9, 3.617125133832136*^9}, 
   3.617235976559976*^9, 3.617239423458297*^9, 3.617239583071122*^9}]
}, Open  ]],

Cell["The fourth term is:", "Text",
 CellChangeTimes->{{3.617124912982442*^9, 3.6171249238727818`*^9}, {
  3.6171250906042337`*^9, 3.61712509213229*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p3", "=", 
  RowBox[{
   SuperscriptBox["t", "6"], 
   RowBox[{"(", 
    RowBox[{"31", 
     RowBox[{
      SuperscriptBox["\[Pi]", "6"], "/", "15120"}]}], ")"}], 
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"newf", ",", "z"}], "]"}], ",", "z"}], "]"}], ",", 
            "z"}], "]"}], ",", "z"}], "]"}], ",", "z"}], "]"}], "/.", 
      RowBox[{"z", "\[Rule]", "x"}]}], ")"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.617124929677779*^9, 3.617124963659987*^9}, {
  3.617125155684092*^9, 3.617125183205412*^9}, {3.617235996306439*^9, 
  3.617235996666781*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"31", " ", 
    SuperscriptBox["\[Pi]", "6"], " ", 
    SuperscriptBox["t", "6"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "x"}], ")"}], " ", 
    SqrtBox[
     RowBox[{"x", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", "x"}], ")"}]}]]}], 
   RowBox[{"1008", " ", 
    SuperscriptBox["x", "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"2", "+", "x"}], ")"}], "4"]}]]}]], "Output",
 CellChangeTimes->{3.61712496415841*^9, 3.61712518385522*^9, 
  3.617235997170361*^9, 3.6172394235602303`*^9, 3.6172395832546797`*^9}]
}, Open  ]],

Cell["The proper terms for the density are:", "Text",
 CellChangeTimes->{{3.617236008771676*^9, 3.61723601672477*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nt", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", "m"}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"p0", ",", "x"}], "]"}], ",", 
       RowBox[{"D", "[", 
        RowBox[{"p1", ",", "x"}], "]"}], ",", 
       RowBox[{"D", "[", 
        RowBox[{"p2", ",", "x"}], "]"}], ",", 
       RowBox[{"D", "[", 
        RowBox[{"p3", ",", "x"}], "]"}]}], "}"}]}], ",", 
    RowBox[{"x", ">", "0"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.617236037524379*^9, 3.617236068575884*^9}, {
  3.61723622571732*^9, 3.6172362284010057`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["x", 
       RowBox[{"9", "/", "2"}]], " ", 
      SqrtBox[
       RowBox[{"2", "+", "x"}]]}], "+", 
     RowBox[{"4", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["x", "5"], " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "x"}], ")"}]}]]}], "+", 
     RowBox[{"4", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["x", "7"], " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "x"}], ")"}]}]]}]}], 
    RowBox[{
     RowBox[{"6", " ", "m", " ", "x"}], "+", 
     RowBox[{"3", " ", "m", " ", 
      SuperscriptBox["x", "2"]}]}]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Pi]", "2"], " ", 
     SuperscriptBox["t", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", "x", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "x"}], ")"}]}]}], ")"}]}], 
    RowBox[{"6", " ", "m", " ", 
     SqrtBox[
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", "x"}], ")"}]}]]}]], ",", 
   FractionBox[
    RowBox[{"7", " ", 
     SuperscriptBox["\[Pi]", "4"], " ", 
     SuperscriptBox["t", "4"]}], 
    RowBox[{"120", " ", "m", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "x"}], ")"}]}], ")"}], 
      RowBox[{"5", "/", "2"}]]}]], ",", 
   FractionBox[
    RowBox[{"31", " ", 
     SuperscriptBox["\[Pi]", "6"], " ", 
     SuperscriptBox["t", "6"], " ", 
     RowBox[{"(", 
      RowBox[{"7", "+", 
       RowBox[{"6", " ", "x", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "x"}], ")"}]}]}], ")"}]}], 
    RowBox[{"1008", " ", "m", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "x"}], ")"}]}], ")"}], 
      RowBox[{"9", "/", "2"}]]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.617236055502597*^9, 3.6172360693650827`*^9}, 
   3.617236230009985*^9, 3.6172394241245003`*^9, 3.6172395839086533`*^9}]
}, Open  ]],

Cell["The first term for the density can be further simplifed:", "Text",
 CellChangeTimes->{{3.61723615842142*^9, 3.6172361676859713`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nt0", "=", 
  RowBox[{
   RowBox[{"Sqrt", "[", "x", "]"}], 
   RowBox[{"Sqrt", "[", 
    RowBox[{"x", "+", "2"}], "]"}], 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"p0", ",", "x"}], "]"}], "/", 
       RowBox[{"Sqrt", "[", "x", "]"}]}], "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"x", "+", "2"}], "]"}]}], ",", 
     RowBox[{"x", ">", "0"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.617236170443529*^9, 3.6172362333986397`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "3"], " ", 
  SuperscriptBox["x", 
   RowBox[{"3", "/", "2"}]], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"2", "+", "x"}], ")"}], 
   RowBox[{"3", "/", "2"}]]}]], "Output",
 CellChangeTimes->{{3.617236183484955*^9, 3.617236233844528*^9}, 
   3.617239424399716*^9, 3.617239584247368*^9}]
}, Open  ]],

Cell["For the entropy:", "Text",
 CellChangeTimes->{{3.617236244455832*^9, 3.617236246398776*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"st", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", "m"}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"p0", ",", "t"}], "]"}], ",", 
       RowBox[{"D", "[", 
        RowBox[{"p1", ",", "t"}], "]"}], ",", 
       RowBox[{"D", "[", 
        RowBox[{"p2", ",", "t"}], "]"}], ",", 
       RowBox[{"D", "[", 
        RowBox[{"p3", ",", "t"}], "]"}]}], "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", ">", "0"}], ",", 
      RowBox[{"t", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.617236037524379*^9, 3.617236068575884*^9}, {
  3.61723622571732*^9, 3.6172362696068983`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Pi]", "2"], " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "x"}], ")"}], " ", 
     SqrtBox[
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", "x"}], ")"}]}]]}], 
    RowBox[{"3", " ", "m"}]], ",", 
   FractionBox[
    RowBox[{"7", " ", 
     SuperscriptBox["\[Pi]", "4"], " ", 
     SuperscriptBox["t", "3"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "x"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", "x", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "x"}], ")"}]}]}], ")"}]}], 
    RowBox[{"90", " ", "m", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "x"}], ")"}]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"31", " ", 
      SuperscriptBox["\[Pi]", "6"], " ", 
      SuperscriptBox["t", "5"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "x"}], ")"}]}], 
     RowBox[{"168", " ", "m", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "x"}], ")"}]}], ")"}], 
       RowBox[{"7", "/", "2"}]]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.617236270226692*^9, 3.617239424721307*^9, 
  3.617239586262886*^9}]
}, Open  ]],

Cell["For dn/d\[Mu]", "Text",
 CellChangeTimes->{{3.617236351455689*^9, 3.617236354294598*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dndmu", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", 
      SuperscriptBox["m", "2"]}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"p0", ",", "x"}], "]"}], ",", "x"}], "]"}], ",", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"p1", ",", "x"}], "]"}], ",", "x"}], "]"}], ",", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"p2", ",", "x"}], "]"}], ",", "x"}], "]"}], ",", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"p3", ",", "x"}], "]"}], ",", "x"}], "]"}]}], "}"}]}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", ">", "0"}], ",", 
      RowBox[{"t", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6172363560286503`*^9, 3.617236401291217*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "x"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["x", "5"], " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", "x"}], ")"}]}]]}], "+", 
       RowBox[{"4", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["x", "7"], " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", "x"}], ")"}]}]]}], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["x", "9"], " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "x"}], ")"}]}]]}], ")"}]}], 
    RowBox[{
     SuperscriptBox["m", "2"], " ", 
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "+", "x"}], ")"}], "2"]}]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Pi]", "2"], " ", 
     SuperscriptBox["t", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "x"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", "x", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "x"}], ")"}]}]}], ")"}]}], 
    RowBox[{"6", " ", 
     SuperscriptBox["m", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "x"}], ")"}]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"7", " ", 
      SuperscriptBox["\[Pi]", "4"], " ", 
      SuperscriptBox["t", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "x"}], ")"}]}], 
     RowBox[{"24", " ", 
      SuperscriptBox["m", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "x"}], ")"}]}], ")"}], 
       RowBox[{"7", "/", "2"}]]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"31", " ", 
      SuperscriptBox["\[Pi]", "6"], " ", 
      SuperscriptBox["t", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "x"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", "x", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "x"}], ")"}]}]}], ")"}]}], 
     RowBox[{"48", " ", 
      SuperscriptBox["m", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "x"}], ")"}]}], ")"}], 
       RowBox[{"11", "/", "2"}]]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6172364034606524`*^9, 3.6172394254468718`*^9, 
  3.617239588246214*^9}]
}, Open  ]],

Cell["The first term again can be further simplified:", "Text",
 CellChangeTimes->{{3.617236464376068*^9, 3.617236470711866*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dndmu1b", "=", 
  RowBox[{
   RowBox[{"Sqrt", "[", "x", "]"}], 
   RowBox[{"Sqrt", "[", 
    RowBox[{"2", "+", "x"}], "]"}], 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"dndmu", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "/", 
       RowBox[{"Sqrt", "[", "x", "]"}]}], "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"2", "+", "x"}], "]"}]}], ",", 
     RowBox[{"x", ">", "0"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.61723647328588*^9, 3.617236528142908*^9}, {
  3.617239816963605*^9, 3.617239821780581*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SqrtBox["x"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "x"}], ")"}], " ", 
   SqrtBox[
    RowBox[{"2", "+", "x"}]]}], 
  SuperscriptBox["m", "2"]]], "Output",
 CellChangeTimes->{{3.617236476627355*^9, 3.617236529217021*^9}, 
   3.6172394257228727`*^9, 3.6172395894503937`*^9, 3.617239822482974*^9}]
}, Open  ]],

Cell["For dn/dT", "Text",
 CellChangeTimes->{{3.617236351455689*^9, 3.617236354294598*^9}, {
  3.6172394090670357`*^9, 3.617239409387306*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dndT", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", 
      SuperscriptBox["m", "2"]}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"p0", ",", "x"}], "]"}], ",", "t"}], "]"}], ",", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"p1", ",", "x"}], "]"}], ",", "t"}], "]"}], ",", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"p2", ",", "x"}], "]"}], ",", "t"}], "]"}], ",", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"p3", ",", "x"}], "]"}], ",", "t"}], "]"}]}], "}"}]}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", ">", "0"}], ",", 
      RowBox[{"t", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6172363560286503`*^9, 3.617236401291217*^9}, {
  3.617239415574185*^9, 3.617239420519848*^9}, {3.6172394557195168`*^9, 
  3.617239460697205*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Pi]", "2"], " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", "x", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "x"}], ")"}]}]}], ")"}]}], 
    RowBox[{"3", " ", 
     SuperscriptBox["m", "2"], " ", 
     SqrtBox[
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", "x"}], ")"}]}]]}]], ",", 
   FractionBox[
    RowBox[{"7", " ", 
     SuperscriptBox["\[Pi]", "4"], " ", 
     SuperscriptBox["t", "3"]}], 
    RowBox[{"30", " ", 
     SuperscriptBox["m", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "x"}], ")"}]}], ")"}], 
      RowBox[{"5", "/", "2"}]]}]], ",", 
   FractionBox[
    RowBox[{"31", " ", 
     SuperscriptBox["\[Pi]", "6"], " ", 
     SuperscriptBox["t", "5"], " ", 
     RowBox[{"(", 
      RowBox[{"7", "+", 
       RowBox[{"6", " ", "x", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "x"}], ")"}]}]}], ")"}]}], 
    RowBox[{"168", " ", 
     SuperscriptBox["m", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "x"}], ")"}]}], ")"}], 
      RowBox[{"9", "/", "2"}]]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.6172364034606524`*^9, 3.617239461502346*^9, 
  3.6172395923153553`*^9}]
}, Open  ]],

Cell["For ds/dT", "Text",
 CellChangeTimes->{{3.617236351455689*^9, 3.617236354294598*^9}, {
  3.6172394090670357`*^9, 3.617239409387306*^9}, {3.617239641127055*^9, 
  3.617239641254964*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dsdT", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", 
      SuperscriptBox["m", "2"]}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"p0", ",", "t"}], "]"}], ",", "t"}], "]"}], ",", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"p1", ",", "t"}], "]"}], ",", "t"}], "]"}], ",", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"p2", ",", "t"}], "]"}], ",", "t"}], "]"}], ",", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"p3", ",", "t"}], "]"}], ",", "t"}], "]"}]}], "}"}]}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", ">", "0"}], ",", 
      RowBox[{"t", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6172363560286503`*^9, 3.617236401291217*^9}, {
  3.617239415574185*^9, 3.617239420519848*^9}, {3.6172394557195168`*^9, 
  3.617239460697205*^9}, {3.6172396428431377`*^9, 3.617239656818234*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Pi]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "x"}], ")"}], " ", 
     SqrtBox[
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", "x"}], ")"}]}]]}], 
    RowBox[{"3", " ", 
     SuperscriptBox["m", "2"]}]], ",", 
   FractionBox[
    RowBox[{"7", " ", 
     SuperscriptBox["\[Pi]", "4"], " ", 
     SuperscriptBox["t", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "x"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", "x", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "x"}], ")"}]}]}], ")"}]}], 
    RowBox[{"30", " ", 
     SuperscriptBox["m", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "x"}], ")"}]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"155", " ", 
      SuperscriptBox["\[Pi]", "6"], " ", 
      SuperscriptBox["t", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "x"}], ")"}]}], 
     RowBox[{"168", " ", 
      SuperscriptBox["m", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "x"}], ")"}]}], ")"}], 
       RowBox[{"7", "/", "2"}]]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6172364034606524`*^9, 3.617239461502346*^9, 
  3.6172395923153553`*^9, 3.617239657743661*^9}]
}, Open  ]],

Cell["For dn/dm", "Text",
 CellChangeTimes->{{3.617236351455689*^9, 3.617236354294598*^9}, {
  3.6172394090670357`*^9, 3.617239409387306*^9}, {3.617239641127055*^9, 
  3.617239641254964*^9}, {3.617239680678115*^9, 3.6172396820540247`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dndm", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"n", "/", "m"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x", "+", "1"}], ")"}], "dndmu1b"}], "+", 
         RowBox[{"t", " ", 
          RowBox[{"dndT", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], ")"}]}], ",", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"n", "/", "m"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x", "+", "1"}], ")"}], 
          RowBox[{"dndmu", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "+", 
         RowBox[{"t", " ", 
          RowBox[{"dndT", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], ")"}]}], ",", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"n", "/", "m"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x", "+", "1"}], ")"}], 
          RowBox[{"dndmu", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], "+", 
         RowBox[{"t", " ", 
          RowBox[{"dndT", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}]}], ")"}]}], ",", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"n", "/", "m"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x", "+", "1"}], ")"}], 
          RowBox[{"dndmu", "[", 
           RowBox[{"[", "4", "]"}], "]"}]}], "+", 
         RowBox[{"t", " ", 
          RowBox[{"dndT", "[", 
           RowBox[{"[", "4", "]"}], "]"}]}]}], ")"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", ">", "0"}], ",", 
      RowBox[{"t", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6172363560286503`*^9, 3.617236401291217*^9}, {
  3.617239415574185*^9, 3.617239420519848*^9}, {3.6172394557195168`*^9, 
  3.617239460697205*^9}, {3.6172396428431377`*^9, 3.6172397985821447`*^9}, {
  3.6172398321251183`*^9, 3.61723990866389*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"m", " ", "n"}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "x"}], ")"}], "2"], " ", 
       SqrtBox[
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "x"}], ")"}]}]]}]}], 
     SuperscriptBox["m", "2"]]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], " ", "m", " ", "n", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "x", " ", 
         SqrtBox[
          RowBox[{"x", " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "x"}], ")"}]}]]}], "+", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["x", "5"], " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", "x"}], ")"}]}]]}], ")"}]}], "-", 
     RowBox[{
      SuperscriptBox["\[Pi]", "2"], " ", 
      SuperscriptBox["t", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"3", " ", "x", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "x"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"2", " ", "x", " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", "x"}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
    RowBox[{"6", " ", 
     SuperscriptBox["m", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "x"}], ")"}]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "120"}], " ", "m", " ", "n"}], "+", 
     FractionBox[
      RowBox[{"7", " ", 
       SuperscriptBox["\[Pi]", "4"], " ", 
       SuperscriptBox["t", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"5", "+", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", "x"}], ")"}]}]}], ")"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "x"}], ")"}]}], ")"}], 
       RowBox[{"7", "/", "2"}]]]}], 
    RowBox[{"120", " ", 
     SuperscriptBox["m", "2"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "336"}], " ", "m", " ", "n"}], "+", 
     FractionBox[
      RowBox[{"31", " ", 
       SuperscriptBox["\[Pi]", "6"], " ", 
       SuperscriptBox["t", "6"], " ", 
       RowBox[{"(", 
        RowBox[{"21", "+", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", "x"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"21", "+", 
            RowBox[{"2", " ", "x", " ", 
             RowBox[{"(", 
              RowBox[{"2", "+", "x"}], ")"}]}]}], ")"}]}]}], ")"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "x"}], ")"}]}], ")"}], 
       RowBox[{"11", "/", "2"}]]]}], 
    RowBox[{"336", " ", 
     SuperscriptBox["m", "2"]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.6172397912454777`*^9, 3.617239799078618*^9}, {
  3.617239833903201*^9, 3.617239854233798*^9}, {3.6172398850925694`*^9, 
  3.617239914541864*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The extremely degenerate and non-relativistic case:", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pEDNR", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{"ped", ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "5"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Psi]", ">", "0"}], "}"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData["ped"], "Output",
 CellChangeTimes->{3.617239425778676*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coefy", "=", 
  RowBox[{"4", " ", 
   RowBox[{"Sqrt", "[", "2", "]"}], " ", 
   SuperscriptBox["\[Psi]", 
    RowBox[{"5", "/", "2"}]], 
   RowBox[{
    SuperscriptBox["t", 
     RowBox[{"5", "/", "2"}]], "/", "15"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["4", "15"], " ", 
  SqrtBox["2"], " ", 
  SuperscriptBox["t", 
   RowBox[{"5", "/", "2"}]], " ", 
  SuperscriptBox["\[Psi]", 
   RowBox[{"5", "/", "2"}]]}]], "Output",
 CellChangeTimes->{3.6172394258619003`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pEDNRsimp", "=", 
  RowBox[{"{", 
   RowBox[{"coefy", ",", 
    RowBox[{"Expand", "[", 
     RowBox[{"pEDNR", "/", "coefy"}], "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["4", "15"], " ", 
    SqrtBox["2"], " ", 
    SuperscriptBox["t", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox["\[Psi]", 
     RowBox[{"5", "/", "2"}]]}], ",", 
   FractionBox[
    RowBox[{"15", " ", "ped"}], 
    RowBox[{"4", " ", 
     SqrtBox["2"], " ", 
     SuperscriptBox["t", 
      RowBox[{"5", "/", "2"}]], " ", 
     SuperscriptBox["\[Psi]", 
      RowBox[{"5", "/", "2"}]]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.617239425944962*^9}]
}, Open  ]],

Cell["There appears to be a typo in the reference?", "Text"],

Cell["Compute the number and energy densities:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Rho]EDNR", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{"pEDNR", ",", "\[Psi]"}], "]"}], "/", "t"}], "]"}]}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.617239426028372*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coefy2", "=", 
  RowBox[{"2", " ", 
   RowBox[{
    RowBox[{"Sqrt", "[", "2", "]"}], "/", "3"}], " ", 
   SuperscriptBox["t", 
    RowBox[{"3", "/", "2"}]], 
   SuperscriptBox["\[Psi]", 
    RowBox[{"3", "/", "2"}]]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["2", "3"], " ", 
  SqrtBox["2"], " ", 
  SuperscriptBox["t", 
   RowBox[{"3", "/", "2"}]], " ", 
  SuperscriptBox["\[Psi]", 
   RowBox[{"3", "/", "2"}]]}]], "Output",
 CellChangeTimes->{3.6172394261106863`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Rho]EDNRsimp", "=", 
  RowBox[{"{", 
   RowBox[{"coefy2", ",", 
    RowBox[{"Expand", "[", 
     RowBox[{"\[Rho]EDNR", "/", "coefy2"}], "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["2", "3"], " ", 
    SqrtBox["2"], " ", 
    SuperscriptBox["t", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["\[Psi]", 
     RowBox[{"3", "/", "2"}]]}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.617239426177547*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CurlyEpsilon]EDNR", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"t", " ", 
      RowBox[{"D", "[", 
       RowBox[{"pEDNR", ",", "t"}], "]"}]}], "-", "pEDNR", "+", 
     "\[Rho]EDNR"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", "ped"}]], "Output",
 CellChangeTimes->{3.617239426297845*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CurlyEpsilon]EDNRsimp", "=", 
  RowBox[{"{", 
   RowBox[{"coefy2", ",", 
    RowBox[{"Expand", "[", 
     RowBox[{"\[CurlyEpsilon]EDNR", "/", "coefy2"}], "]"}]}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["2", "3"], " ", 
    SqrtBox["2"], " ", 
    SuperscriptBox["t", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["\[Psi]", 
     RowBox[{"3", "/", "2"}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", " ", "ped"}], 
     RowBox[{"2", " ", 
      SqrtBox["2"], " ", 
      SuperscriptBox["t", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["\[Psi]", 
       RowBox[{"3", "/", "2"}]]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.617239426357759*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The extremely degenerate and extremely relativistic case:", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p2", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{"ped", ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "\[Infinity]", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"\[Psi]", ">", "0"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData["ped"], "Output",
 CellChangeTimes->{3.617239426425888*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"p2big", "=", 
   RowBox[{"Series", "[", 
    RowBox[{"ped", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "\[Infinity]", ",", "2"}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pEDER", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Normal", "[", 
       RowBox[{"Series", "[", 
        RowBox[{"ped", ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "\[Infinity]", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}], "]"}], ",", 
      RowBox[{"SeriesCoefficient", "[", 
       RowBox[{"p2big", ",", "0"}], "]"}], ",", 
      RowBox[{"SeriesCoefficient", "[", 
       RowBox[{"p2big", ",", "1"}], "]"}], ",", 
      RowBox[{"SeriesCoefficient", "[", 
       RowBox[{"p2big", ",", "2"}], "]"}]}], "}"}], ",", 
    RowBox[{"\[Psi]", ">", "0"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"ped", ",", "ped", ",", 
   RowBox[{"SeriesCoefficient", "[", 
    RowBox[{"ped", ",", "1"}], "]"}], ",", 
   RowBox[{"SeriesCoefficient", "[", 
    RowBox[{"ped", ",", "2"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.617239426652741*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coefz", "=", 
  RowBox[{
   SuperscriptBox["\[Psi]", "4"], 
   RowBox[{
    SuperscriptBox["t", "4"], "/", "12"}]}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["\[Psi]", "4"]}], "12"]], "Output",
 CellChangeTimes->{3.617239426725585*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pEDERsimp", "=", 
  RowBox[{"{", 
   RowBox[{"coefz", ",", 
    RowBox[{"Expand", "[", 
     RowBox[{"pEDER", "/", "coefz"}], "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["t", "4"], " ", 
     SuperscriptBox["\[Psi]", "4"]}], "12"], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"12", " ", "ped"}], 
      RowBox[{
       SuperscriptBox["t", "4"], " ", 
       SuperscriptBox["\[Psi]", "4"]}]], ",", 
     FractionBox[
      RowBox[{"12", " ", "ped"}], 
      RowBox[{
       SuperscriptBox["t", "4"], " ", 
       SuperscriptBox["\[Psi]", "4"]}]], ",", 
     FractionBox[
      RowBox[{"12", " ", 
       RowBox[{"SeriesCoefficient", "[", 
        RowBox[{"ped", ",", "1"}], "]"}]}], 
      RowBox[{
       SuperscriptBox["t", "4"], " ", 
       SuperscriptBox["\[Psi]", "4"]}]], ",", 
     FractionBox[
      RowBox[{"12", " ", 
       RowBox[{"SeriesCoefficient", "[", 
        RowBox[{"ped", ",", "2"}], "]"}]}], 
      RowBox[{
       SuperscriptBox["t", "4"], " ", 
       SuperscriptBox["\[Psi]", "4"]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.617239426808401*^9}]
}, Open  ]],

Cell["Compute the number and energy densities:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Rho]EDER", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{"pEDER", ",", "\[Psi]"}], "]"}], "/", "t"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.61723942689102*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coefz2", "=", 
  RowBox[{
   SuperscriptBox["t", "3"], 
   RowBox[{
    SuperscriptBox["\[Psi]", "3"], "/", "3"}]}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["t", "3"], " ", 
   SuperscriptBox["\[Psi]", "3"]}], "3"]], "Output",
 CellChangeTimes->{3.617239426973691*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Rho]EDERsimp", "=", 
  RowBox[{"{", 
   RowBox[{"coefz2", ",", 
    RowBox[{"Expand", "[", 
     RowBox[{"\[Rho]EDER", "/", "coefz2"}], "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["t", "3"], " ", 
     SuperscriptBox["\[Psi]", "3"]}], "3"], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.617239427057742*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CurlyEpsilon]EDER", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"t", " ", 
      RowBox[{"D", "[", 
       RowBox[{"pEDER", ",", "t"}], "]"}]}], "-", "pEDER", "+", 
     "\[Rho]EDER"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "ped"}], ",", 
   RowBox[{"-", "ped"}], ",", 
   RowBox[{"-", 
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{"ped", ",", "1"}], "]"}]}], ",", 
   RowBox[{"-", 
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{"ped", ",", "2"}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.617239427140674*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coefz3", "=", 
  RowBox[{
   SuperscriptBox["\[Psi]", "4"], 
   RowBox[{
    SuperscriptBox["t", "4"], "/", "4"}]}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["t", "4"], " ", 
   SuperscriptBox["\[Psi]", "4"]}], "4"]], "Output",
 CellChangeTimes->{3.61723942722377*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"coefz3", ",", 
   RowBox[{"Expand", "[", 
    RowBox[{"\[CurlyEpsilon]EDER", "/", "coefz3"}], "]"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["t", "4"], " ", 
     SuperscriptBox["\[Psi]", "4"]}], "4"], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "ped"}], 
       RowBox[{
        SuperscriptBox["t", "4"], " ", 
        SuperscriptBox["\[Psi]", "4"]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "ped"}], 
       RowBox[{
        SuperscriptBox["t", "4"], " ", 
        SuperscriptBox["\[Psi]", "4"]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"ped", ",", "1"}], "]"}]}], 
       RowBox[{
        SuperscriptBox["t", "4"], " ", 
        SuperscriptBox["\[Psi]", "4"]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"ped", ",", "2"}], "]"}]}], 
       RowBox[{
        SuperscriptBox["t", "4"], " ", 
        SuperscriptBox["\[Psi]", "4"]}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6172394273068*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Massless pair formulas", "Section"],

Cell[CellGroupData[{

Cell["\<\
The expression for the chemical potential 'nu' in terms of n, g, T:\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sqt", "=", 
  RowBox[{"Sqrt", "[", 
   RowBox[{
    RowBox[{"729", " ", 
     SuperscriptBox["n", "2"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["g", "2"], 
     SuperscriptBox["\[Pi]", "2"], 
     SuperscriptBox["T", "6"]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 SqrtBox[
  RowBox[{
   RowBox[{"729", " ", 
    SuperscriptBox["n", "2"]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["g", "2"], " ", 
    SuperscriptBox["\[Pi]", "2"], " ", 
    SuperscriptBox["T", "6"]}]}]]], "Output",
 CellChangeTimes->{3.6172394273895063`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cbt", "=", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "27"}], " ", "n"}], "+", "sqt"}], ")"}], 
   RowBox[{"1", "/", "3"}]]}]], "Input"],

Cell[BoxData[
 SuperscriptBox[
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "27"}], " ", "n"}], "+", 
    SqrtBox[
     RowBox[{
      RowBox[{"729", " ", 
       SuperscriptBox["n", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["g", "2"], " ", 
       SuperscriptBox["\[Pi]", "2"], " ", 
       SuperscriptBox["T", "6"]}]}]]}], ")"}], 
  RowBox[{"1", "/", "3"}]]], "Output",
 CellChangeTimes->{3.617239427472734*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nu", "=", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"g", " ", 
       RowBox[{
        SuperscriptBox["\[Pi]", "4"], "/", "3"}]}], ")"}], 
     RowBox[{"1", "/", "3"}]], 
    RowBox[{
     SuperscriptBox["T", "2"], "/", "cbt"}]}], "-", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Pi]", "2"], "/", "9"}], "/", "g"}], ")"}], 
     RowBox[{"1", "/", "3"}]], "cbt"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"1", "/", "3"}]], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"4", "/", "3"}]], " ", 
    SuperscriptBox["T", "2"]}], 
   RowBox[{
    SuperscriptBox["3", 
     RowBox[{"1", "/", "3"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "27"}], " ", "n"}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"729", " ", 
          SuperscriptBox["n", "2"]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["g", "2"], " ", 
          SuperscriptBox["\[Pi]", "2"], " ", 
          SuperscriptBox["T", "6"]}]}]]}], ")"}], 
     RowBox[{"1", "/", "3"}]]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["1", "g"], ")"}], 
     RowBox[{"1", "/", "3"}]], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"2", "/", "3"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "27"}], " ", "n"}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"729", " ", 
          SuperscriptBox["n", "2"]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["g", "2"], " ", 
          SuperscriptBox["\[Pi]", "2"], " ", 
          SuperscriptBox["T", "6"]}]}]]}], ")"}], 
     RowBox[{"1", "/", "3"}]]}], 
   SuperscriptBox["3", 
    RowBox[{"2", "/", "3"}]]]}]], "Output",
 CellChangeTimes->{3.617239427556407*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Rephrase cbt in terms of a convenient variable \[Alpha]:\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cbt2", "=", 
  RowBox[{"3", " ", 
   SuperscriptBox["n", 
    RowBox[{"1", "/", "3"}]], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"729", " ", 
             SuperscriptBox["n", "2"]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["g", "2"], 
             SuperscriptBox["\[Pi]", "2"], 
             SuperscriptBox["T", "6"]}]}], ")"}], "/", "729"}], "/", 
         SuperscriptBox["n", "2"]}], "]"}], "]"}]}], ")"}], 
    RowBox[{"1", "/", "3"}]]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"3", " ", 
  SuperscriptBox["n", 
   RowBox[{"1", "/", "3"}]], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SqrtBox[
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["g", "2"], " ", 
         SuperscriptBox["\[Pi]", "2"], " ", 
         SuperscriptBox["T", "6"]}], 
        RowBox[{"243", " ", 
         SuperscriptBox["n", "2"]}]]}]]}], ")"}], 
   RowBox[{"1", "/", "3"}]]}]], "Output",
 CellChangeTimes->{3.617239427766068*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cbt3", "=", 
  RowBox[{"3", " ", 
   SuperscriptBox["n", 
    RowBox[{"1", "/", "3"}]], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SqrtBox[
       RowBox[{"1", "+", "\[Alpha]"}]]}], ")"}], 
    RowBox[{"1", "/", "3"}]]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"3", " ", 
  SuperscriptBox["n", 
   RowBox[{"1", "/", "3"}]], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SqrtBox[
      RowBox[{"1", "+", "\[Alpha]"}]]}], ")"}], 
   RowBox[{"1", "/", "3"}]]}]], "Output",
 CellChangeTimes->{3.617239427838148*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Alpha]0", "=", 
  RowBox[{
   SuperscriptBox["g", "2"], 
   SuperscriptBox["\[Pi]", "2"], 
   RowBox[{
    RowBox[{
     SuperscriptBox["T", "6"], "/", "243"}], "/", 
    SuperscriptBox["n", "2"]}]}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["g", "2"], " ", 
   SuperscriptBox["\[Pi]", "2"], " ", 
   SuperscriptBox["T", "6"]}], 
  RowBox[{"243", " ", 
   SuperscriptBox["n", "2"]}]]], "Output",
 CellChangeTimes->{3.617239427920458*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Rewrite 'nu' completely in terms of \[Alpha]\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cbt4", "=", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SqrtBox[
       RowBox[{"1", "+", "\[Alpha]"}]]}], ")"}], 
    RowBox[{"1", "/", "3"}]], "/", 
   SuperscriptBox["\[Alpha]", 
    RowBox[{"1", "/", "6"}]]}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SqrtBox[
      RowBox[{"1", "+", "\[Alpha]"}]]}], ")"}], 
   RowBox[{"1", "/", "3"}]], 
  SuperscriptBox["\[Alpha]", 
   RowBox[{"1", "/", "6"}]]]], "Output",
 CellChangeTimes->{3.617239427987362*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nu2", "=", 
  RowBox[{"\[Pi]", " ", 
   RowBox[{"T", "/", 
    RowBox[{"Sqrt", "[", "3", "]"}]}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"1", "/", "cbt4"}], "-", "cbt4"}], ")"}]}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[Pi]", " ", "T", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      SuperscriptBox["\[Alpha]", 
       RowBox[{"1", "/", "6"}]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SqrtBox[
          RowBox[{"1", "+", "\[Alpha]"}]]}], ")"}], 
       RowBox[{"1", "/", "3"}]]], "-", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SqrtBox[
          RowBox[{"1", "+", "\[Alpha]"}]]}], ")"}], 
       RowBox[{"1", "/", "3"}]], 
      SuperscriptBox["\[Alpha]", 
       RowBox[{"1", "/", "6"}]]]}], ")"}]}], 
  SqrtBox["3"]]], "Output",
 CellChangeTimes->{3.6172394280719147`*^9}]
}, Open  ]],

Cell["Demonstrate that these are the same:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nu", "/.", 
       RowBox[{"g", "\[Rule]", "1"}]}], "/.", 
      RowBox[{"n", "\[Rule]", "2"}]}], "/.", 
     RowBox[{"T", "\[Rule]", "3"}]}], "]"}], ",", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"nu2", "/.", 
        RowBox[{"\[Alpha]", "\[Rule]", "\[Alpha]0"}]}], "/.", 
       RowBox[{"g", "\[Rule]", "1"}]}], "/.", 
      RowBox[{"n", "\[Rule]", "2"}]}], "/.", 
     RowBox[{"T", "\[Rule]", "3"}]}], "]"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.3081326069695542`", ",", "1.3081326069695556`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.61723942821842*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nu", "/.", 
       RowBox[{"g", "\[Rule]", "3"}]}], "/.", 
      RowBox[{"n", "\[Rule]", "1"}]}], "/.", 
     RowBox[{"T", "\[Rule]", "2"}]}], "]"}], ",", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"nu2", "/.", 
        RowBox[{"\[Alpha]", "\[Rule]", "\[Alpha]0"}]}], "/.", 
       RowBox[{"g", "\[Rule]", "3"}]}], "/.", 
      RowBox[{"n", "\[Rule]", "1"}]}], "/.", 
     RowBox[{"T", "\[Rule]", "2"}]}], "]"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.4968923844549411`", ",", "0.4968923844549409`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.617239428423999*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nu", "/.", 
       RowBox[{"g", "\[Rule]", "2"}]}], "/.", 
      RowBox[{"n", "\[Rule]", "3"}]}], "/.", 
     RowBox[{"T", "\[Rule]", "1"}]}], "]"}], ",", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"nu2", "/.", 
        RowBox[{"\[Alpha]", "\[Rule]", "\[Alpha]0"}]}], "/.", 
       RowBox[{"g", "\[Rule]", "2"}]}], "/.", 
      RowBox[{"n", "\[Rule]", "3"}]}], "/.", 
     RowBox[{"T", "\[Rule]", "1"}]}], "]"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.7322794788504523`", ",", "3.7322794788504527`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.617239428567934*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nu", "/.", 
       RowBox[{"g", "\[Rule]", "1"}]}], "/.", 
      RowBox[{"n", "\[Rule]", "3"}]}], "/.", 
     RowBox[{"T", "\[Rule]", "2"}]}], "]"}], ",", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"nu2", "/.", 
        RowBox[{"\[Alpha]", "\[Rule]", "\[Alpha]0"}]}], "/.", 
       RowBox[{"g", "\[Rule]", "1"}]}], "/.", 
      RowBox[{"n", "\[Rule]", "3"}]}], "/.", 
     RowBox[{"T", "\[Rule]", "2"}]}], "]"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.455166354351411`", ",", "3.455166354351409`"}], "}"}]], "Output",\

 CellChangeTimes->{3.6172394287126093`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nu", "/.", 
       RowBox[{"g", "\[Rule]", "3"}]}], "/.", 
      RowBox[{"n", "\[Rule]", "2"}]}], "/.", 
     RowBox[{"T", "\[Rule]", "1"}]}], "]"}], ",", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"nu2", "/.", 
        RowBox[{"\[Alpha]", "\[Rule]", "\[Alpha]0"}]}], "/.", 
       RowBox[{"g", "\[Rule]", "3"}]}], "/.", 
      RowBox[{"n", "\[Rule]", "2"}]}], "/.", 
     RowBox[{"T", "\[Rule]", "1"}]}], "]"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.471109692946823`", ",", "2.4711096929468246`"}], "}"}]], "Output",\

 CellChangeTimes->{3.6172394288334627`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"nu", "/.", 
       RowBox[{"g", "\[Rule]", "2"}]}], "/.", 
      RowBox[{"n", "\[Rule]", "1"}]}], "/.", 
     RowBox[{"T", "\[Rule]", "3"}]}], "]"}], ",", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"nu2", "/.", 
        RowBox[{"\[Alpha]", "\[Rule]", "\[Alpha]0"}]}], "/.", 
       RowBox[{"g", "\[Rule]", "2"}]}], "/.", 
      RowBox[{"n", "\[Rule]", "1"}]}], "/.", 
     RowBox[{"T", "\[Rule]", "3"}]}], "]"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.33291793064328434`", ",", "0.3329179306432842`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.617239429054942*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Some series expansions:", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"nu2", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "/", "\[Pi]"}], "/", "T"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Alpha]", ",", "0", ",", "3"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    SuperscriptBox["2", 
     RowBox[{"1", "/", "3"}]], 
    SuperscriptBox["\[Alpha]", 
     RowBox[{"1", "/", "6"}]]], "-", 
   FractionBox[
    SuperscriptBox["\[Alpha]", 
     RowBox[{"1", "/", "6"}]], 
    SuperscriptBox["2", 
     RowBox[{"1", "/", "3"}]]], "+", 
   FractionBox[
    SuperscriptBox["\[Alpha]", 
     RowBox[{"5", "/", "6"}]], 
    RowBox[{"6", " ", 
     SuperscriptBox["2", 
      RowBox[{"2", "/", "3"}]]}]], "+", 
   FractionBox[
    SuperscriptBox["\[Alpha]", 
     RowBox[{"7", "/", "6"}]], 
    RowBox[{"12", " ", 
     SuperscriptBox["2", 
      RowBox[{"1", "/", "3"}]]}]], "-", 
   FractionBox[
    SuperscriptBox["\[Alpha]", 
     RowBox[{"11", "/", "6"}]], 
    RowBox[{"18", " ", 
     SuperscriptBox["2", 
      RowBox[{"2", "/", "3"}]]}]], "-", 
   FractionBox[
    RowBox[{"5", " ", 
     SuperscriptBox["\[Alpha]", 
      RowBox[{"13", "/", "6"}]]}], 
    RowBox[{"144", " ", 
     SuperscriptBox["2", 
      RowBox[{"1", "/", "3"}]]}]], "+", 
   FractionBox[
    RowBox[{"77", " ", 
     SuperscriptBox["\[Alpha]", 
      RowBox[{"17", "/", "6"}]]}], 
    RowBox[{"2592", " ", 
     SuperscriptBox["2", 
      RowBox[{"2", "/", "3"}]]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Alpha]", "]"}], 
     RowBox[{"19", "/", "6"}]],
    SeriesData[$CellContext`\[Alpha], 0, {}, -1, 19, 6],
    Editable->False]}],
  SeriesData[$CellContext`\[Alpha], 0, {
   2^Rational[1, 3], 0, -2^Rational[-1, 3], 0, 0, 0, Rational[1, 6] 
    2^Rational[-2, 3], 0, Rational[1, 12] 2^Rational[-1, 3], 0, 0, 0, 
    Rational[-1, 18] 2^Rational[-2, 3], 0, Rational[-5, 144] 
    2^Rational[-1, 3], 0, 0, 0, Rational[77, 2592] 2^Rational[-2, 3]}, -1, 19,
    6],
  Editable->False]], "Output",
 CellChangeTimes->{3.617239429283931*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"nu2", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", "3", "]"}], "/", "\[Pi]"}], "/", "T"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Alpha]", ",", "\[Infinity]", ",", "3"}], "}"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", 
     SqrtBox[
      FractionBox["1", "\[Alpha]"]]}], "3"], "-", 
   RowBox[{
    FractionBox["8", "81"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["1", "\[Alpha]"], ")"}], 
     RowBox[{"3", "/", "2"}]]}], "+", 
   RowBox[{
    FractionBox["32", "729"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["1", "\[Alpha]"], ")"}], 
     RowBox[{"5", "/", "2"}]]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "\[Alpha]"], "]"}], 
     RowBox[{"19", "/", "6"}]],
    SeriesData[$CellContext`\[Alpha], 
     DirectedInfinity[1], {}, 3, 19, 6],
    Editable->False]}],
  SeriesData[$CellContext`\[Alpha], 
   DirectedInfinity[1], {
    Rational[2, 3], 0, 0, 0, 0, 0, 
    Rational[-8, 81], 0, 0, 0, 0, 0, 
    Rational[32, 729]}, 3, 19, 6],
  Editable->False]], "Output",
 CellChangeTimes->{3.617239429350965*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Trying different degenerate expansions\
\>", "Section",
 CellChangeTimes->{{3.617131122476807*^9, 3.617131127709152*^9}}],

Cell["\<\
Perform the integration by parts to get the new pressure:\
\>", "Text",
 CellChangeTimes->{{3.617205426913186*^9, 3.61720543632129*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ipv", "=", 
   RowBox[{
    SuperscriptBox["k", "2"], "g", " ", 
    RowBox[{"T", "/", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", " ", "\[Pi]"}], ")"}], "3"]}], 
    RowBox[{"(", 
     RowBox[{"4", " ", "\[Pi]"}], ")"}]}]}], ";", " ", 
  RowBox[{"ipu", "=", 
   RowBox[{"Log", "[", 
    RowBox[{"1", "+", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           SuperscriptBox["k", "2"], "+", 
           SuperscriptBox["m", "2"]}], "]"}]}], "/", "T"}], "+", 
       RowBox[{"\[Mu]", "/", "T"}]}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.617205320232667*^9, 3.6172053931122007`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"iand2", "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"D", "[", 
     RowBox[{"ipu", ",", "k"}], "]"}]}], 
   RowBox[{"Integrate", "[", 
    RowBox[{"ipv", ",", "k"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.617205395022833*^9, 3.617205424808283*^9}, 
   3.617205533560626*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       SqrtBox[
        RowBox[{
         SuperscriptBox["k", "2"], "+", 
         SuperscriptBox["m", "2"]}]], "T"]}], "+", 
     FractionBox["\[Mu]", "T"]}]], " ", "g", " ", 
   SuperscriptBox["k", "4"]}], 
  RowBox[{"6", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         SqrtBox[
          RowBox[{
           SuperscriptBox["k", "2"], "+", 
           SuperscriptBox["m", "2"]}]], "T"]}], "+", 
       FractionBox["\[Mu]", "T"]}]]}], ")"}], " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["k", "2"], "+", 
     SuperscriptBox["m", "2"]}]], " ", 
   SuperscriptBox["\[Pi]", "2"]}]]], "Output",
 CellChangeTimes->{3.617205411465075*^9, 3.617205501019994*^9, 
  3.617205533906314*^9, 3.617239429578026*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"iand3", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"g", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["k", "2"], "/", "2"}], "/", 
      SuperscriptBox["\[Pi]", "2"]}]}], ")"}], 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["k", "2"], "/", "3"}], "/", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       SuperscriptBox["k", "2"], "+", 
       SuperscriptBox["m", "2"]}], "]"}]}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           SuperscriptBox["k", "2"], "+", 
           SuperscriptBox["m", "2"]}], "]"}], "/", "T"}], "-", 
        RowBox[{"\[Mu]", "/", "T"}]}], "]"}]}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.617205440064251*^9, 3.617205491780238*^9}, {
  3.617205524559959*^9, 3.6172055293193083`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"g", " ", 
   SuperscriptBox["k", "4"]}], 
  RowBox[{"6", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       FractionBox[
        SqrtBox[
         RowBox[{
          SuperscriptBox["k", "2"], "+", 
          SuperscriptBox["m", "2"]}]], "T"], "-", 
       FractionBox["\[Mu]", "T"]}]]}], ")"}], " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["k", "2"], "+", 
     SuperscriptBox["m", "2"]}]], " ", 
   SuperscriptBox["\[Pi]", "2"]}]]], "Output",
 CellChangeTimes->{{3.617205492147233*^9, 3.617205534903061*^9}, 
   3.6172394296329737`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"iand2", "/", "iand3"}], "]"}]], "Input",
 CellChangeTimes->{{3.617205493083753*^9, 3.617205496900732*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.6172054973665533`*^9, 3.617205503196266*^9}, 
   3.617205535815401*^9, 3.617239429843833*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"iandpf", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"g", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["k", "2"], "/", "2"}], "/", 
      SuperscriptBox["\[Pi]", "2"]}]}], ")"}], 
   RowBox[{
    RowBox[{
     SuperscriptBox["k", "2"], "/", "3"}], "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", 
      SuperscriptBox["m", "2"]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.617205602115183*^9, 3.617205613533154*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"g", " ", 
   SuperscriptBox["k", "4"]}], 
  RowBox[{"6", " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["k", "2"], "+", 
     SuperscriptBox["m", "2"]}]], " ", 
   SuperscriptBox["\[Pi]", "2"]}]]], "Output",
 CellChangeTimes->{3.617205614193165*^9, 3.617239429899147*^9}]
}, Open  ]],

Cell["This is the JEL version:", "Text",
 CellChangeTimes->{{3.61713165132861*^9, 3.6171316739248323`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lhs", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            SuperscriptBox["k", "2"], "+", 
            SuperscriptBox["m", "2"]}], "]"}], "-", "\[Mu]"}], ")"}], "/", 
        "T"}], "/.", 
       RowBox[{"k", "\[Rule]", 
        RowBox[{"ell", " ", "m"}]}]}], "/.", 
      RowBox[{"\[Mu]", "\[Rule]", 
       RowBox[{
        RowBox[{"\[Psi]", " ", "T"}], "+", "m"}]}]}], "/.", 
     RowBox[{"m", "\[Rule]", 
      RowBox[{"T", "/", "t"}]}]}], ",", 
    RowBox[{"T", ">", "0"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.617131238265483*^9, 3.617131279712634*^9}, {
  3.617131316079397*^9, 3.617131338982628*^9}, {3.617131390162675*^9, 
  3.617131411421557*^9}, {3.617131620244136*^9, 3.617131640680499*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   RowBox[{"t", " ", 
    RowBox[{"(", 
     RowBox[{
      SqrtBox[
       FractionBox[
        RowBox[{"1", "+", 
         SuperscriptBox["ell", "2"]}], 
        SuperscriptBox["t", "2"]]], "-", "\[Psi]"}], ")"}]}]}], 
  "t"]], "Output",
 CellChangeTimes->{{3.617131260472527*^9, 3.6171313393467083`*^9}, 
   3.61713141189217*^9, {3.617131621909863*^9, 3.617131641507453*^9}, 
   3.617132013428514*^9, 3.61720561909544*^9, 3.6172394299817038`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"lhs", "\[Equal]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"z", "/", "t"}], "-", "\[Psi]"}], ")"}]}], ",", "z"}], "]"}], 
   ",", 
   RowBox[{"t", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.617131130722599*^9, 3.6171312356133823`*^9}, {
  3.617131369333405*^9, 3.617131369762973*^9}, {3.617132005407085*^9, 
  3.6171320088891163`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"z", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SqrtBox[
      RowBox[{"1", "+", 
       SuperscriptBox["ell", "2"]}]]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.6171312085451317`*^9, 3.61713137033807*^9, 3.617131416642857*^9, {
   3.617131623372636*^9, 3.617131642722248*^9}, {3.617132009344891*^9, 
   3.617132014009584*^9}, 3.617205621005584*^9, 3.617239430048403*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"iandpf", "/.", 
     RowBox[{"k", "\[Rule]", 
      RowBox[{"ell", " ", "m"}]}]}], "/.", 
    RowBox[{"\[Mu]", "\[Rule]", 
     RowBox[{
      RowBox[{"\[Psi]", " ", "T"}], "+", "m"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"t", ">", "0"}], ",", 
     RowBox[{"T", ">", "0"}], ",", 
     RowBox[{"m", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.617205627544684*^9, 3.61720564797364*^9}, {
  3.617205692926063*^9, 3.6172056996286182`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["ell", "4"], " ", "g", " ", 
   SuperscriptBox["m", "3"]}], 
  RowBox[{"6", " ", 
   SqrtBox[
    RowBox[{"1", "+", 
     SuperscriptBox["ell", "2"]}]], " ", 
   SuperscriptBox["\[Pi]", "2"]}]]], "Output",
 CellChangeTimes->{{3.617205634688476*^9, 3.6172056483899307`*^9}, {
   3.6172056938665037`*^9, 3.617205700042486*^9}, 3.617239430182096*^9}]
}, Open  ]],

Cell["This is an alternate way of recasting the integral:", "Text",
 CellChangeTimes->{{3.6171316910010347`*^9, 3.617131694320936*^9}, {
  3.617131784684794*^9, 3.617131795247959*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lhs", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            SuperscriptBox["k", "2"], "+", 
            SuperscriptBox["m", "2"]}], "]"}], "-", "\[Mu]"}], ")"}], "/", 
        "T"}], "/.", 
       RowBox[{"k", "\[Rule]", 
        RowBox[{"u", " ", "m"}]}]}], "/.", 
      RowBox[{"\[Mu]", "\[Rule]", 
       RowBox[{"\[Psi]", " ", "T"}]}]}], "/.", 
     RowBox[{"m", "\[Rule]", 
      RowBox[{"mot", " ", "T"}]}]}], ",", 
    RowBox[{"T", ">", "0"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.617131238265483*^9, 3.617131279712634*^9}, {
  3.617131316079397*^9, 3.617131338982628*^9}, {3.617131390162675*^9, 
  3.617131411421557*^9}, {3.617131620244136*^9, 3.617131640680499*^9}, {
  3.6171316876600018`*^9, 3.6171317640988417`*^9}, {3.617131985683301*^9, 
  3.617131985923192*^9}}],

Cell[BoxData[
 RowBox[{
  SqrtBox[
   RowBox[{
    SuperscriptBox["mot", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["u", "2"]}], ")"}]}]], "-", "\[Psi]"}]], "Output",
 CellChangeTimes->{
  3.6171317088588123`*^9, {3.6171317489001083`*^9, 3.617131764579589*^9}, 
   3.617131986854208*^9, 3.617132017000218*^9, 3.617205954224581*^9, 
   3.617239430313675*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{"lhs", "\[Equal]", 
     RowBox[{"z", "-", "\[Psi]"}]}], "]"}], ",", 
   RowBox[{"mot", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.617131130722599*^9, 3.6171312356133823`*^9}, {
  3.617131369333405*^9, 3.617131369762973*^9}, {3.617131816060938*^9, 
  3.6171318194947653`*^9}, {3.617131999342971*^9, 3.6171320425997066`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"z", "\[Rule]", 
    RowBox[{"mot", " ", 
     SqrtBox[
      RowBox[{"1", "+", 
       SuperscriptBox["u", "2"]}]]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.61713202519945*^9, 3.617132043042618*^9}, 
   3.617205954905346*^9, 3.6172394305487537`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"iandpf", "/.", 
     RowBox[{"k", "\[Rule]", 
      RowBox[{"u", " ", "m"}]}]}], "/.", 
    RowBox[{"\[Mu]", "\[Rule]", 
     RowBox[{"\[Psi]", " ", "T"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"T", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"m", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.617205770269333*^9, 3.6172058286408653`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"g", " ", 
   SuperscriptBox["m", "3"], " ", 
   SuperscriptBox["u", "4"]}], 
  RowBox[{"6", " ", 
   SuperscriptBox["\[Pi]", "2"], " ", 
   SqrtBox[
    RowBox[{"1", "+", 
     SuperscriptBox["u", "2"]}]]}]]], "Output",
 CellChangeTimes->{{3.617205771228097*^9, 3.617205829010119*^9}, 
   3.617205955685295*^9, 3.61723943069562*^9}]
}, Open  ]],

Cell["Another alternate:", "Text",
 CellChangeTimes->{{3.6171316910010347`*^9, 3.617131694320936*^9}, {
  3.617131784684794*^9, 3.617131795247959*^9}, {3.617205857397957*^9, 
  3.6172058642802353`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lhs", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            SuperscriptBox["k", "2"], "+", 
            SuperscriptBox["m", "2"]}], "]"}], "-", "\[Mu]"}], ")"}], "/", 
        "T"}], "/.", 
       RowBox[{"k", "\[Rule]", 
        RowBox[{"u", " ", "T"}]}]}], "/.", 
      RowBox[{"\[Mu]", "\[Rule]", 
       RowBox[{"\[Psi]", " ", "T"}]}]}], "/.", 
     RowBox[{"m", "\[Rule]", 
      RowBox[{"mot", " ", "T"}]}]}], ",", 
    RowBox[{"T", ">", "0"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.617131238265483*^9, 3.617131279712634*^9}, {
  3.617131316079397*^9, 3.617131338982628*^9}, {3.617131390162675*^9, 
  3.617131411421557*^9}, {3.617131620244136*^9, 3.617131640680499*^9}, {
  3.6171316876600018`*^9, 3.6171317640988417`*^9}, {3.617131985683301*^9, 
  3.617131985923192*^9}, {3.617205866712305*^9, 3.617205866946989*^9}}],

Cell[BoxData[
 RowBox[{
  SqrtBox[
   RowBox[{
    SuperscriptBox["mot", "2"], "+", 
    SuperscriptBox["u", "2"]}]], "-", "\[Psi]"}]], "Output",
 CellChangeTimes->{
  3.6171317088588123`*^9, {3.6171317489001083`*^9, 3.617131764579589*^9}, 
   3.617131986854208*^9, 3.617132017000218*^9, 3.61720586746*^9, 
   3.617239430889489*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{"lhs", "\[Equal]", 
     RowBox[{"z", "-", "\[Psi]"}]}], "]"}], ",", 
   RowBox[{"mot", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.617131130722599*^9, 3.6171312356133823`*^9}, {
  3.617131369333405*^9, 3.617131369762973*^9}, {3.617131816060938*^9, 
  3.6171318194947653`*^9}, {3.617131999342971*^9, 3.6171320425997066`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"z", "\[Rule]", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["mot", "2"], "+", 
      SuperscriptBox["u", "2"]}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.61713202519945*^9, 3.617132043042618*^9}, 
   3.617205871338827*^9, 3.617239430944879*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"iandpf", "/.", 
      RowBox[{"k", "\[Rule]", 
       RowBox[{"u", " ", "T"}]}]}], "/.", 
     RowBox[{"\[Mu]", "\[Rule]", 
      RowBox[{"\[Psi]", " ", "T"}]}]}], "/.", 
    RowBox[{"m", "\[Rule]", 
     RowBox[{"mot", " ", "T"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"T", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"m", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.617205770269333*^9, 3.6172058286408653`*^9}, {
  3.617205876068302*^9, 3.617205905044179*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"g", " ", 
   SuperscriptBox["T", "3"], " ", 
   SuperscriptBox["u", "4"]}], 
  RowBox[{"6", " ", 
   SuperscriptBox["\[Pi]", "2"], " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["mot", "2"], "+", 
     SuperscriptBox["u", "2"]}]]}]]], "Output",
 CellChangeTimes->{{3.617205771228097*^9, 3.617205829010119*^9}, {
   3.617205876810004*^9, 3.617205905526988*^9}, 3.617239431010425*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Determining dn/dm:", "Section",
 CellChangeTimes->{{3.617471912105551*^9, 3.617471916401082*^9}}],

Cell["\<\
In terms of integrals of f dk (with inc_rest_mass=false)\
\>", "Text",
 CellChangeTimes->{{3.617472021880999*^9, 3.61747202997698*^9}, {
  3.617472265257375*^9, 3.617472269440597*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"n", "=", 
  SuperscriptBox["k", "2"]}]], "Input",
 CellChangeTimes->{{3.6174719541708117`*^9, 3.617471956419157*^9}}],

Cell[BoxData[
 SuperscriptBox["k", "2"]], "Output",
 CellChangeTimes->{3.6174719574494677`*^9, 3.617484800691629*^9, 
  3.6174858712025127`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dndmu", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["k", "2"], "+", 
     SuperscriptBox["En", "2"]}], ")"}], "/", "En"}]}]], "Input",
 CellChangeTimes->{{3.617471919565713*^9, 3.617471951731803*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["En", "2"], "+", 
   SuperscriptBox["k", "2"]}], "En"]], "Output",
 CellChangeTimes->{{3.6174719445129642`*^9, 3.617471959745068*^9}, 
   3.617484810423394*^9, 3.61748587134066*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dndT", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"]}], "+", 
     SuperscriptBox["En", "2"], "-", 
     RowBox[{"En", 
      RowBox[{"(", 
       RowBox[{"\[Mu]", "+", "m"}], ")"}]}], "-", 
     RowBox[{
      SuperscriptBox["k", "2"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]", "+", "m"}], ")"}], "/", "En"}]}]}], ")"}], "/", 
   "T"}]}]], "Input",
 CellChangeTimes->{{3.6174719658231077`*^9, 3.617472014669139*^9}, 
   3.617472138478614*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["En", "2"], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["k", "2"]}], "-", 
   RowBox[{"En", " ", 
    RowBox[{"(", 
     RowBox[{"m", "+", "\[Mu]"}], ")"}]}], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"m", "+", "\[Mu]"}], ")"}]}], "En"]}], "T"]], "Output",
 CellChangeTimes->{3.6174720151041603`*^9, 3.6174721389933157`*^9, 
  3.617484824453422*^9, 3.617485871390366*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dndm", "=", 
  RowBox[{"-", "ms"}]}]], "Input",
 CellChangeTimes->{{3.6174720498395853`*^9, 3.617472060851056*^9}, 
   3.6174848269158573`*^9}],

Cell[BoxData[
 RowBox[{"-", "ms"}]], "Output",
 CellChangeTimes->{3.617472065765147*^9, 3.6174721398367777`*^9, 
  3.617484827512594*^9, 3.617485871439666*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{"n", "/", "ms"}]}], "-", 
     RowBox[{
      RowBox[{"T", "/", "ms"}], " ", "dndT"}], "-", 
     RowBox[{
      RowBox[{"\[Mu]", "/", "ms"}], " ", "dndmu"}]}], ")"}], "/.", 
   RowBox[{"En", "\[Rule]", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", 
      SuperscriptBox["ms", "2"]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.61747206799135*^9, 3.6174721471669188`*^9}, {
  3.617484836893772*^9, 3.617484986420874*^9}, {3.617485052482231*^9, 
  3.617485245525524*^9}, {3.6174853516132507`*^9, 3.61748543472682*^9}, {
  3.6174854695198793`*^9, 3.617485590202001*^9}, {3.617485688370714*^9, 
  3.617485692199848*^9}, {3.61748575406103*^9, 3.6174857713726673`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["k", "2"], " ", "m"}], 
   RowBox[{"ms", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["k", "2"], "+", 
      SuperscriptBox["ms", "2"]}]]}]], "+", 
  RowBox[{"ms", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     FractionBox["m", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["k", "2"], "+", 
        SuperscriptBox["ms", "2"]}]]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.617485384739931*^9, 3.617485395998301*^9}, 
   3.6174854351445503`*^9, {3.617485504752365*^9, 3.617485590602228*^9}, 
   3.617485692708112*^9, 3.617485772181426*^9, 3.6174858714902*^9}]
}, Open  ]],

Cell["In terms of integrals of f dk (with inc_rest_mass=true)", "Text",
 CellChangeTimes->{{3.617472021880999*^9, 3.61747202997698*^9}, {
  3.617472265257375*^9, 3.617472294384355*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"n", "=", 
  SuperscriptBox["k", "2"]}]], "Input",
 CellChangeTimes->{{3.6174719541708117`*^9, 3.617471956419157*^9}}],

Cell[BoxData[
 SuperscriptBox["k", "2"]], "Output",
 CellChangeTimes->{3.6174719574494677`*^9, 3.617472173921155*^9, 
  3.617485286163989*^9, 3.6174858715728407`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dndmu", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["k", "2"], "+", 
     SuperscriptBox["En", "2"]}], ")"}], "/", "En"}]}]], "Input",
 CellChangeTimes->{{3.617471919565713*^9, 3.617471951731803*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["En", "2"], "+", 
   SuperscriptBox["k", "2"]}], "En"]], "Output",
 CellChangeTimes->{{3.6174719445129642`*^9, 3.617471959745068*^9}, 
   3.617472174572954*^9, 3.617485287358962*^9, 3.617485871624172*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dndT", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"]}], "+", 
     SuperscriptBox["En", "2"], "-", 
     RowBox[{"En", 
      RowBox[{"(", "\[Mu]", ")"}]}], "-", 
     RowBox[{
      SuperscriptBox["k", "2"], 
      RowBox[{
       RowBox[{"(", "\[Mu]", ")"}], "/", "En"}]}]}], ")"}], "/", 
   "T"}]}]], "Input",
 CellChangeTimes->{{3.6174719658231077`*^9, 3.617472014669139*^9}, {
  3.617472138478614*^9, 3.6174721694290333`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["En", "2"], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["k", "2"]}], "-", 
   RowBox[{"En", " ", "\[Mu]"}], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["k", "2"], " ", "\[Mu]"}], "En"]}], "T"]], "Output",
 CellChangeTimes->{3.6174720151041603`*^9, 3.6174721389933157`*^9, 
  3.617472175217146*^9, 3.6174852886560097`*^9, 3.6174858716731157`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dndm", "=", 
  RowBox[{"-", "ms"}]}]], "Input",
 CellChangeTimes->{{3.6174720498395853`*^9, 3.617472060851056*^9}, 
   3.617485299552635*^9}],

Cell[BoxData[
 RowBox[{"-", "ms"}]], "Output",
 CellChangeTimes->{
  3.617472065765147*^9, 3.6174721398367777`*^9, 3.6174721758837013`*^9, {
   3.617485292238614*^9, 3.617485306625016*^9}, 3.617485871722547*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", 
      RowBox[{"n", "/", "ms"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"dndT", "+", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]", "-", "ms"}], ")"}], "/", "T"}], " ", "dndmu"}]}], 
       ")"}], 
      RowBox[{"T", "/", "ms"}]}], "-", "dndmu"}], ")"}], "/.", 
   RowBox[{"En", "\[Rule]", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", 
      SuperscriptBox["ms", "2"]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.61747206799135*^9, 3.6174721471669188`*^9}, {
  3.617472199127179*^9, 3.6174722004147*^9}, {3.6174853116601973`*^9, 
  3.617485319645583*^9}}],

Cell[BoxData[
 RowBox[{"-", "ms"}]], "Output",
 CellChangeTimes->{{3.617472106528494*^9, 3.617472147523944*^9}, {
   3.617472178969149*^9, 3.6174722009788847`*^9}, {3.6174852937369423`*^9, 
   3.617485320190818*^9}, 3.617485871771914*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", 
      RowBox[{"n", "/", "ms"}]}], "-", 
     RowBox[{"dndT", " ", 
      RowBox[{"T", "/", "ms"}]}], "-", 
     RowBox[{
      RowBox[{
       RowBox[{"(", "\[Mu]", ")"}], "/", "ms"}], " ", "dndmu"}]}], ")"}], "/.", 
   RowBox[{"En", "\[Rule]", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", 
      SuperscriptBox["ms", "2"]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.61747206799135*^9, 3.6174721471669188`*^9}, {
  3.617472199127179*^9, 3.6174722004147*^9}, {3.6174853116601973`*^9, 
  3.617485319645583*^9}, {3.617485857300887*^9, 3.617485901797605*^9}}],

Cell[BoxData[
 RowBox[{"-", "ms"}]], "Output",
 CellChangeTimes->{{3.617472106528494*^9, 3.617472147523944*^9}, {
  3.617472178969149*^9, 3.6174722009788847`*^9}, {3.6174852937369423`*^9, 
  3.617485320190818*^9}, {3.617485871820758*^9, 3.617485902197879*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{809, 948},
WindowMargins->{{735, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"9.0 for Linux x86 (64-bit) (February 7, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 64, 0, 81, "Section"],
Cell[634, 24, 139, 3, 31, "Text"],
Cell[CellGroupData[{
Cell[798, 31, 60, 0, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[883, 35, 390, 14, 35, "Input"],
Cell[1276, 51, 465, 15, 64, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1778, 71, 335, 10, 32, "Input"],
Cell[2116, 83, 764, 24, 85, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2917, 112, 241, 7, 32, "Input"],
Cell[3161, 121, 1132, 35, 88, "Output"]
}, Open  ]],
Cell[4308, 159, 85, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[4418, 165, 392, 13, 37, "Input"],
Cell[4813, 180, 508, 17, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5358, 202, 278, 8, 32, "Input"],
Cell[5639, 212, 1251, 42, 86, "Output"]
}, Open  ]],
Cell[6905, 257, 58, 0, 31, "Text"],
Cell[CellGroupData[{
Cell[6988, 261, 144, 4, 32, "Input"],
Cell[7135, 267, 1137, 35, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8309, 307, 683, 22, 59, "Input"],
Cell[8995, 331, 1193, 40, 86, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10225, 376, 240, 7, 32, "Input"],
Cell[10468, 385, 1225, 37, 136, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11730, 427, 710, 22, 59, "Input"],
Cell[12443, 451, 1347, 45, 138, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13839, 502, 169, 3, 59, "Subsubsection"],
Cell[14011, 507, 155, 3, 32, "Text"],
Cell[14169, 512, 657, 21, 35, "Input"],
Cell[14829, 535, 724, 21, 35, "Input"],
Cell[CellGroupData[{
Cell[15578, 560, 404, 9, 32, "Input"],
Cell[15985, 571, 277, 6, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16299, 582, 352, 9, 32, "Input"],
Cell[16654, 593, 275, 6, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16966, 604, 572, 18, 76, "Input"],
Cell[17541, 624, 534, 17, 71, "Output"]
}, Open  ]],
Cell[18090, 644, 93, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[18208, 649, 449, 13, 32, "Input"],
Cell[18660, 664, 556, 18, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19253, 687, 204, 5, 32, "Input"],
Cell[19460, 694, 72, 1, 32, "Output"]
}, Open  ]],
Cell[19547, 698, 104, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[19676, 703, 657, 20, 32, "Input"],
Cell[20336, 725, 1829, 58, 174, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22202, 788, 1036, 33, 127, "Input"],
Cell[23241, 823, 151, 3, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23429, 831, 153, 3, 32, "Input"],
Cell[23585, 836, 189, 6, 54, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[23823, 848, 67, 0, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[23915, 852, 311, 11, 35, "Input"],
Cell[24229, 865, 385, 12, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24651, 882, 285, 9, 32, "Input"],
Cell[24939, 893, 1419, 42, 101, "Output"]
}, Open  ]],
Cell[26373, 938, 46, 0, 31, "Text"],
Cell[CellGroupData[{
Cell[26444, 942, 548, 16, 55, "Input"],
Cell[26995, 960, 923, 29, 101, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27955, 994, 232, 7, 32, "Input"],
Cell[28190, 1003, 1898, 59, 183, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30125, 1067, 320, 11, 35, "Input"],
Cell[30448, 1080, 395, 12, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30880, 1097, 177, 5, 32, "Input"],
Cell[31060, 1104, 2293, 75, 183, "Output"]
}, Open  ]],
Cell[33368, 1182, 56, 0, 31, "Text"],
Cell[CellGroupData[{
Cell[33449, 1186, 144, 4, 32, "Input"],
Cell[33596, 1192, 1778, 55, 181, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35411, 1252, 321, 11, 35, "Input"],
Cell[35735, 1265, 395, 12, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36167, 1282, 189, 5, 32, "Input"],
Cell[36359, 1289, 2295, 75, 183, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38691, 1369, 240, 7, 32, "Input"],
Cell[38934, 1378, 2746, 84, 235, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41717, 1467, 316, 11, 35, "Input"],
Cell[42036, 1480, 399, 12, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42472, 1497, 211, 6, 32, "Input"],
Cell[42686, 1505, 3344, 108, 232, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[46079, 1619, 55, 0, 35, "Subsubsection"],
Cell[46137, 1621, 153, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[46315, 1628, 829, 26, 35, "Input"],
Cell[47147, 1656, 799, 26, 98, "Output"]
}, Open  ]],
Cell[47961, 1685, 304, 12, 44, "Text"],
Cell[CellGroupData[{
Cell[48290, 1701, 252, 9, 35, "Input"],
Cell[48545, 1712, 299, 10, 69, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48881, 1727, 213, 7, 32, "Input"],
Cell[49097, 1736, 254, 7, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49388, 1748, 1094, 35, 105, "Input"],
Cell[50485, 1785, 584, 19, 77, "Output"]
}, Open  ]],
Cell[51084, 1807, 50, 0, 31, "Text"],
Cell[CellGroupData[{
Cell[51159, 1811, 671, 21, 35, "Input"],
Cell[51833, 1834, 308, 10, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52178, 1849, 502, 15, 35, "Input"],
Cell[52683, 1866, 252, 8, 62, "Output"]
}, Open  ]],
Cell[52950, 1877, 48, 0, 31, "Text"],
Cell[CellGroupData[{
Cell[53023, 1881, 344, 11, 56, "Input"],
Cell[53370, 1894, 309, 10, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53716, 1909, 288, 9, 32, "Input"],
Cell[54007, 1920, 117, 2, 32, "Output"]
}, Open  ]],
Cell[54139, 1925, 473, 13, 79, "Text"],
Cell[54615, 1940, 238, 5, 74, "Text"],
Cell[CellGroupData[{
Cell[54878, 1949, 2029, 54, 121, "Input"],
Cell[56910, 2005, 2065, 64, 103, "Output"]
}, Open  ]],
Cell[58990, 2072, 126, 3, 31, "Text"],
Cell[CellGroupData[{
Cell[59141, 2079, 517, 17, 35, "Input"],
Cell[59661, 2098, 558, 19, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60256, 2122, 256, 6, 32, "Input"],
Cell[60515, 2130, 350, 9, 54, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[60914, 2145, 166, 3, 35, "Subsubsection"],
Cell[61083, 2150, 175, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[61283, 2158, 520, 13, 32, "Input"],
Cell[61806, 2173, 1054, 35, 83, "Output"]
}, Open  ]],
Cell[62875, 2211, 135, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[63035, 2216, 449, 12, 32, "Input"],
Cell[63487, 2230, 565, 15, 63, "Output"]
}, Open  ]],
Cell[64067, 2248, 103, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[64195, 2253, 437, 13, 35, "Input"],
Cell[64635, 2268, 423, 13, 54, "Output"]
}, Open  ]],
Cell[65073, 2284, 153, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[65251, 2290, 690, 21, 35, "Input"],
Cell[65944, 2313, 705, 22, 60, "Output"]
}, Open  ]],
Cell[66664, 2338, 153, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[66842, 2344, 846, 25, 35, "Input"],
Cell[67691, 2371, 600, 18, 63, "Output"]
}, Open  ]],
Cell[68306, 2392, 118, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[68449, 2397, 625, 18, 32, "Input"],
Cell[69077, 2417, 2062, 68, 125, "Output"]
}, Open  ]],
Cell[71154, 2488, 139, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[71318, 2493, 537, 16, 32, "Input"],
Cell[71858, 2511, 340, 10, 54, "Output"]
}, Open  ]],
Cell[72213, 2524, 98, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[72336, 2529, 705, 21, 32, "Input"],
Cell[73044, 2552, 1438, 47, 64, "Output"]
}, Open  ]],
Cell[74497, 2602, 95, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[74617, 2607, 957, 30, 105, "Input"],
Cell[75577, 2639, 2632, 88, 135, "Output"]
}, Open  ]],
Cell[78224, 2730, 129, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[78378, 2735, 590, 17, 55, "Input"],
Cell[78971, 2754, 345, 10, 63, "Output"]
}, Open  ]],
Cell[79331, 2767, 142, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[79498, 2773, 1056, 32, 105, "Input"],
Cell[80557, 2807, 1439, 47, 63, "Output"]
}, Open  ]],
Cell[82011, 2857, 191, 3, 31, "Text"],
Cell[CellGroupData[{
Cell[82227, 2864, 1104, 32, 105, "Input"],
Cell[83334, 2898, 1537, 50, 71, "Output"]
}, Open  ]],
Cell[84886, 2951, 239, 3, 31, "Text"],
Cell[CellGroupData[{
Cell[85150, 2958, 2013, 59, 99, "Input"],
Cell[87166, 3019, 3182, 103, 216, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[90397, 3128, 76, 0, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[90498, 3132, 377, 11, 32, "Input"],
Cell[90878, 3145, 72, 1, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[90987, 3151, 255, 8, 37, "Input"],
Cell[91245, 3161, 249, 8, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91531, 3174, 177, 5, 32, "Input"],
Cell[91711, 3181, 529, 18, 63, "Output"]
}, Open  ]],
Cell[92255, 3202, 60, 0, 31, "Text"],
Cell[92318, 3204, 56, 0, 31, "Text"],
Cell[CellGroupData[{
Cell[92399, 3208, 180, 5, 32, "Input"],
Cell[92582, 3215, 70, 1, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[92689, 3221, 254, 8, 34, "Input"],
Cell[92946, 3231, 248, 8, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[93231, 3244, 189, 5, 32, "Input"],
Cell[93423, 3251, 305, 10, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[93765, 3266, 280, 8, 32, "Input"],
Cell[94048, 3276, 89, 2, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[94174, 3283, 211, 6, 32, "Input"],
Cell[94388, 3291, 554, 19, 63, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[94991, 3316, 84, 1, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[95100, 3321, 383, 11, 32, "Input"],
Cell[95486, 3334, 72, 1, 32, "Output"]
}, Open  ]],
Cell[95573, 3338, 208, 7, 32, "Input"],
Cell[CellGroupData[{
Cell[95806, 3349, 667, 18, 77, "Input"],
Cell[96476, 3369, 283, 7, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96796, 3381, 152, 5, 35, "Input"],
Cell[96951, 3388, 169, 5, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97157, 3398, 177, 5, 32, "Input"],
Cell[97337, 3405, 1023, 33, 111, "Output"]
}, Open  ]],
Cell[98375, 3441, 56, 0, 31, "Text"],
Cell[CellGroupData[{
Cell[98456, 3445, 180, 5, 32, "Input"],
Cell[98639, 3452, 134, 3, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98810, 3460, 152, 5, 35, "Input"],
Cell[98965, 3467, 168, 5, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[99170, 3477, 189, 5, 32, "Input"],
Cell[99362, 3484, 290, 9, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[99689, 3498, 280, 8, 32, "Input"],
Cell[99972, 3508, 363, 11, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100372, 3524, 152, 5, 35, "Input"],
Cell[100527, 3531, 167, 5, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100731, 3541, 159, 4, 32, "Input"],
Cell[100893, 3547, 1124, 37, 111, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[102078, 3591, 41, 0, 81, "Section"],
Cell[CellGroupData[{
Cell[102144, 3595, 100, 2, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[102269, 3601, 280, 9, 35, "Input"],
Cell[102552, 3612, 284, 9, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[102873, 3626, 199, 7, 34, "Input"],
Cell[103075, 3635, 446, 15, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103558, 3655, 501, 18, 38, "Input"],
Cell[104062, 3675, 1457, 50, 101, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[105568, 3731, 89, 2, 36, "Subsubsection"],
Cell[CellGroupData[{
Cell[105682, 3737, 705, 22, 38, "Input"],
Cell[106390, 3761, 534, 18, 73, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[106961, 3784, 304, 11, 41, "Input"],
Cell[107268, 3797, 317, 11, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107622, 3813, 238, 8, 34, "Input"],
Cell[107863, 3823, 252, 8, 51, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[108164, 3837, 77, 2, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[108266, 3843, 306, 11, 41, "Input"],
Cell[108575, 3856, 312, 11, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[108924, 3872, 221, 7, 28, "Input"],
Cell[109148, 3881, 754, 26, 77, "Output"]
}, Open  ]],
Cell[109917, 3910, 52, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[109994, 3914, 572, 18, 28, "Input"],
Cell[110569, 3934, 153, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[110759, 3943, 572, 18, 28, "Input"],
Cell[111334, 3963, 154, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[111525, 3972, 572, 18, 28, "Input"],
Cell[112100, 3992, 154, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112291, 4001, 572, 18, 28, "Input"],
Cell[112866, 4021, 153, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113056, 4030, 572, 18, 28, "Input"],
Cell[113631, 4050, 154, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113822, 4059, 572, 18, 28, "Input"],
Cell[114397, 4079, 155, 4, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[114601, 4089, 48, 0, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[114674, 4093, 264, 8, 28, "Input"],
Cell[114941, 4103, 1846, 58, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116824, 4166, 277, 9, 28, "Input"],
Cell[117104, 4177, 977, 33, 75, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[118142, 4217, 131, 3, 80, "Section"],
Cell[118276, 4222, 146, 3, 30, "Text"],
Cell[118425, 4227, 738, 23, 35, "Input"],
Cell[CellGroupData[{
Cell[119188, 4254, 304, 9, 28, "Input"],
Cell[119495, 4265, 940, 31, 101, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[120472, 4301, 883, 28, 35, "Input"],
Cell[121358, 4331, 639, 21, 85, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[122034, 4357, 158, 3, 28, "Input"],
Cell[122195, 4362, 144, 2, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[122376, 4369, 492, 16, 35, "Input"],
Cell[122871, 4387, 314, 10, 61, "Output"]
}, Open  ]],
Cell[123200, 4400, 107, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[123332, 4405, 888, 25, 35, "Input"],
Cell[124223, 4432, 517, 15, 77, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[124777, 4452, 462, 13, 28, "Input"],
Cell[125242, 4467, 456, 12, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[125735, 4484, 547, 16, 28, "Input"],
Cell[126285, 4502, 404, 11, 61, "Output"]
}, Open  ]],
Cell[126704, 4516, 184, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[126913, 4522, 961, 26, 35, "Input"],
Cell[127877, 4550, 389, 11, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128303, 4566, 424, 9, 28, "Input"],
Cell[128730, 4577, 316, 9, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[129083, 4591, 470, 14, 28, "Input"],
Cell[129556, 4607, 371, 11, 61, "Output"]
}, Open  ]],
Cell[129942, 4621, 202, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[130169, 4628, 1007, 26, 35, "Input"],
Cell[131179, 4656, 332, 9, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[131548, 4670, 424, 9, 28, "Input"],
Cell[131975, 4681, 314, 9, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[132326, 4695, 609, 18, 28, "Input"],
Cell[132938, 4715, 425, 12, 61, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[133412, 4733, 103, 1, 80, "Section"],
Cell[133518, 4736, 194, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[133737, 4744, 141, 3, 32, "Input"],
Cell[133881, 4749, 144, 3, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[134062, 4757, 247, 7, 35, "Input"],
Cell[134312, 4766, 238, 6, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[134587, 4777, 543, 18, 35, "Input"],
Cell[135133, 4797, 494, 15, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[135664, 4817, 167, 4, 28, "Input"],
Cell[135834, 4823, 159, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[136030, 4831, 823, 20, 35, "Input"],
Cell[136856, 4853, 684, 21, 66, "Output"]
}, Open  ]],
Cell[137555, 4877, 185, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[137765, 4883, 141, 3, 32, "Input"],
Cell[137909, 4888, 166, 3, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[138112, 4896, 247, 7, 35, "Input"],
Cell[138362, 4905, 261, 6, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[138660, 4916, 511, 16, 35, "Input"],
Cell[139174, 4934, 416, 11, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[139627, 4950, 165, 4, 28, "Input"],
Cell[139795, 4956, 211, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[140043, 4965, 759, 23, 35, "Input"],
Cell[140805, 4990, 238, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[141080, 4999, 702, 19, 35, "Input"],
Cell[141785, 5020, 260, 4, 28, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
